@@ -6,5 +6,5 @@ if [ -z "$1" ]; then
   exit
 fi
 
-find boost libs -type f ! -regex '.*/\(\.\|CVS/\|Makefile\|SConscript\).*' \
+find boost libs -type f ! -regex '.*/\(\.\|CVS/\|Makefile\|CMake\|SConscript\).*' \
 -exec sh -c "if [ -e '$1/{}' ]; then cp -fp '$1/{}' '{}'; chmod u+w '{}'; else rm -f '{}'; fi" \;
