@@ -24,7 +24,7 @@
 
 #  define ATOMIC_OPS_X86_GNUC
 
-#elif defined(_X86_) && defined(_MSC_VER)
+#elif defined(_M_IX86) && defined(_MSC_VER)
 
 #  define ATOMIC_OPS_X86_MSC
 
