@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,13 +61,37 @@ private:
 };
 
 
+/**
+ * \brief Default implementation of intrusive referencing.
+ *
+ * May be specialized or overloaded.
+ */
+template<typename T>
+inline void intrusive_ref(T& obj)
+{
+	obj.ref();
+}
+
+
+/**
+ * \brief Default implementation of intrusive unreferencing.
+ *
+ * May be specialized or overloaded.
+ */
+template<typename T>
+inline void intrusive_unref(T& obj)
+{
+	obj.unref();
+}
+
+
 template<typename T>
 inline
 IntrusivePtr<T>::IntrusivePtr(T* obj)
 :	m_pObj(obj)
 {
 	if (obj)
-		obj->ref();
+		intrusive_ref(*obj);
 }
 
 template<typename T>
@@ -76,7 +100,7 @@ IntrusivePtr<T>::IntrusivePtr(IntrusivePtr const& other)
 :	m_pObj(other.m_pObj)
 {
 	if (m_pObj)
-		m_pObj->ref();
+		intrusive_ref(*m_pObj);
 }
 
 template<typename T>
@@ -86,7 +110,7 @@ IntrusivePtr<T>::IntrusivePtr(IntrusivePtr<OT> const& other)
 :	m_pObj(other.get())
 {
 	if (m_pObj)
-		m_pObj->ref();
+		intrusive_ref(*m_pObj);
 }
 
 template<typename T>
@@ -94,7 +118,7 @@ inline
 IntrusivePtr<T>::~IntrusivePtr()
 {
 	if (m_pObj)
-		m_pObj->unref();
+		intrusive_unref(*m_pObj);
 }
 
 template<typename T>
