@@ -36,11 +36,11 @@ public:
 	
 	~RefCountableSAP() { this->close(); }
 	
-	void ref() { ++m_refCounter; }
+	void ref() const { ++m_refCounter; }
 	
-	void unref() { if (!--m_refCounter) delete this; }
+	void unref() const { if (!--m_refCounter) delete this; }
 private:
-	AtomicCounter<ACE_MT_SYNCH> m_refCounter;
+	mutable AtomicCounter<ACE_MT_SYNCH> m_refCounter;
 };
 
 #endif
