@@ -27,6 +27,7 @@
 #include "SplittableBuffer.h"
 #include "IntrusivePtr.h"
 #include <stddef.h>
+#include <iosfwd>
 #include <streambuf>
 
 class DataChunk;
@@ -39,6 +40,8 @@ public:
 	
 	virtual ~SBOutStreamBuf();
 	
+	size_t readChunk(std::istream& strm);
+	
 	SplittableBuffer& data() { return m_buf; }
 	
 	SplittableBuffer const& data() const { return m_buf; }
@@ -53,8 +56,6 @@ protected:
 	
 	virtual std::streamsize xsputn(char_type const* s, std::streamsize n);
 private:
-	BString* getAdjacentBlock();
-	
 	void nextChunk();
 	
 	size_t m_chunkSize;
