@@ -258,6 +258,12 @@ public:
 	template<typename T>
 	static T parseUnsigned(const std::string& str);
 	
+	template<typename T, typename Iter>
+	static T parseSigned(Iter begin, Iter& end);
+	
+	template<typename T>
+	static T parseSigned(const std::string& str);
+	
 	template<typename T, typename Iter>
 	static T parseUnsignedHex(Iter begin, Iter& end);
 private:
@@ -759,6 +765,38 @@ StringUtils::parseUnsigned(const std::string& str)
 	return parseUnsigned<T>(str.data(), end);
 }
 
+template<typename T, typename Iter>
+T
+StringUtils::parseSigned(Iter begin, Iter& end)
+{
+	T val = 0;
+	
+	if (begin == end) {
+		return val;
+	}
+	
+	char sign = *begin;
+	if (sign == '+' || sign == '-') {
+		++begin;
+	} else {
+		//sign = '+'; // not really necessary
+	}
+	
+	val = parseUnsigned<T>(begin, end);
+	if (sign == '-') {
+		val = -val;
+	}
+	return val;
+}
+
+template<typename T>
+inline T
+StringUtils::parseSigned(const std::string& str)
+{
+	const char* end = str.data() + str.length();
+	return parseSigned<T>(str.data(), end);
+}
+
 template<typename T, typename Iter>
 T
 StringUtils::parseUnsignedHex(Iter begin, Iter& end)
