@@ -46,7 +46,8 @@ std::string num2str(T val)
 LexGen::LexGen(const char* core_class, const char* subclass)
 :	m_core_class(core_class),
 	m_subclass(subclass),
-	m_trackTokenPosition(false),
+	m_trackStreamPosition(false),
+	m_trackLineCol(false),
 	m_rule_id_generator(0)
 {
 }
@@ -358,7 +359,9 @@ LexGen::writeLexer(std::ostream& header, std::ostream& impl,
 	substitutions["@NUM_NON_DEADEND_STATES@"] = num2str(num_non_deadend_states);
 	substitutions["@TRANSITION_TYPE@"] = transition_type;
 	substitutions["@TRANSITION_INDEX_TYPE@"] = transition_index_type;
-	substitutions["@TRACK_TOKEN_POSITION@"] = m_trackTokenPosition ? "1" : "0";
+	substitutions["@TRACK_STREAM_POSITION@"] = m_trackStreamPosition ? "1" : "0";
+	substitutions["@TRACK_LINE_COL@"] = m_trackLineCol ? "1" : "0";
+	substitutions["@TRACKING_ENABLED@"] = (m_trackStreamPosition || m_trackLineCol) ? "1" : "0";
 	
 	writeSkel(header, header_skel, substitutions);
 	writeSkel(impl, impl_skel, substitutions);
