@@ -161,6 +161,11 @@ private:
 	static JSBool documentGetElementsByTagName(
 		JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 	
+	static JSBool documentCreateElement(
+		JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
+	
+	static JSBool createDivElement(JSContext *cx, JSObject *obj, jsval *rval);
+	
 	static JSBool imageConstructor(
 		JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 	
@@ -401,6 +406,7 @@ JsEnvironment::Context::Context(URI const& page_url)
 	jsDefineProperty(nav_obj, "userAgent", STRING_TO_JSVAL(jsNewStringCopyZ(
 		"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8) Gecko/20051111 Firefox/1.5"
 	)), RO);
+	jsDefineProperty(nav_obj, "language", STRING_TO_JSVAL(jsNewStringCopyZ("en")), RO);
 	
 	JSObject* mimetypes_array = jsNewArrayObject(0, 0);
 	jsDefineProperty(nav_obj, "mimeTypes", OBJECT_TO_JSVAL(mimetypes_array), RO);
@@ -460,6 +466,7 @@ JsEnvironment::Context::Context(URI const& page_url)
 	jsDefineFunction(m_pDocumentObj, "writeln", &documentWriteln, 1, RW);
 	jsDefineFunction(m_pDocumentObj, "getElementById", &documentGetElementById, 1, RW);
 	jsDefineFunction(m_pDocumentObj, "getElementsByTagName", &documentGetElementsByTagName, 1, RW);
+	jsDefineFunction(m_pDocumentObj, "createElement", &documentCreateElement, 1, RW);
 	jsDefineFunction(m_pDocumentObj, "open", &doNothing, 0, RW);
 	jsDefineFunction(m_pDocumentObj, "close", &doNothing, 0, RW);
 	jsDefineProperty(
@@ -814,6 +821,32 @@ JsEnvironment::Context::processDocumentWrite(
 JSBool
 JsEnvironment::Context::documentGetElementById(
 	JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+	return createDivElement(cx, obj, rval);
+}
+
+JSBool
+JsEnvironment::Context::documentGetElementsByTagName(
+	JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+	JSObject* empty_array = JS_NewArrayObject(cx, 0, 0);
+	if (!empty_array) {
+		return JS_FALSE;
+	}
+	*rval = OBJECT_TO_JSVAL(empty_array);
+	return JS_TRUE;
+}
+
+JSBool
+JsEnvironment::Context::documentCreateElement(
+	JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+	return createDivElement(cx, obj, rval);
+}
+
+JSBool
+JsEnvironment::Context::createDivElement(
+	JSContext *cx, JSObject *obj, jsval *rval)
 {
 	JSObject* el = JS_NewObject(cx, &m_sDivClass, 0, 0);
 	if (!el) {
@@ -867,18 +900,6 @@ JsEnvironment::Context::documentGetElementById(
 	return JS_TRUE;
 }
 
-JSBool
-JsEnvironment::Context::documentGetElementsByTagName(
-	JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
-{
-	JSObject* empty_array = JS_NewArrayObject(cx, 0, 0);
-	if (!empty_array) {
-		return JS_FALSE;
-	}
-	*rval = OBJECT_TO_JSVAL(empty_array);
-	return JS_TRUE;
-}
-
 JSBool
 JsEnvironment::Context::imageConstructor(
 	JSContext* cx, JSObject* obj, uintN argc, jsval* argv, jsval* rval)
