@@ -27,8 +27,7 @@
 #include "NonCopyable.h"
 #include <string>
 #include <memory>
-#include <deque>
-#include <map>
+#include <vector>
 
 class BString;
 class FilterTag;
@@ -44,13 +43,14 @@ public:
 	
 	std::auto_ptr<std::string> performAction(
 		FilterTag const& filter_tag, FilterGroupTag const& group_tag,
-		std::string const& js_code, std::deque<BString> const& params);
+		std::string const& js_code, std::vector<BString> const& params);
 private:
 	enum { STACK_SIZE = 5*1024 };
 	
 	class Impl;
+	class JsException;
 	
-	std::auto_ptr<Impl> m_pImpl;
+	std::auto_ptr<Impl> m_ptrImpl;
 };
 
 #endif
