@@ -22,6 +22,7 @@
 #endif
 
 #include "prthread.h"
+#include <ace/OS_NS_Thread.h>
 #include <errno.h>
 
 PRThread* PR_GetCurrentThread()
@@ -31,3 +32,30 @@ PRThread* PR_GetCurrentThread()
 	// errno fits perfectly here.
 	return reinterpret_cast<PRThread*>(&errno);
 }
+
+PRStatus PR_NewThreadPrivateIndex(
+	PRUintn* newIndex, PRThreadPrivateDTOR destructor)
+{
+	ACE_thread_key_t key;
+	if (ACE_OS::thr_keycreate(&key, destructor) == -1) {
+		return PR_FAILURE;
+	} else {
+		*newIndex = static_cast<PRUintn>(key);
+		return PR_SUCCESS;
+	}
+}
+
+
+PRStatus PR_SetThreadPrivate(PRUintn tpdIndex, void* priv)
+{
+	ACE_thread_key_t key = static_cast<ACE_thread_key_t>(tpdIndex);
+	return static_cast<PRStatus>(ACE_OS::thr_setspecific(key, priv));
+}
+
+void* PR_GetThreadPrivate(PRUintn tpdIndex)
+{
+	void* data = 0;
+	ACE_thread_key_t key = static_cast<ACE_thread_key_t>(tpdIndex);
+	ACE_OS::thr_getspecific(key, &data);
+	return data;
+}
