@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,23 +24,17 @@
 #include <config.h>
 #endif
 
-#include "RefCountable.h"
-#include "RefCounter.h"
-#include "IntrusivePtr.h"
+#include "RequestStatus.h"
 
 class SplittableBuffer;
-class ErrorDescriptor;
 
-class AbstractRequestHandler
-:	public RefCountable<RefCounter<ACE_NULL_SYNCH> >
+class AbstractRequestHandler : public RequestStatus
 {
 public:
 	virtual ~AbstractRequestHandler() {}
 
 	// postcondition: data is empty
 	virtual void appendBodyData(SplittableBuffer& data, bool eof) = 0;
-	
-	virtual void cancelRequest(IntrusivePtr<ErrorDescriptor> const& edesc) = 0;
 };
 
 #endif
