@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 class HttpResponseMetadata;
 class SplittableBuffer;
 class ErrorDescriptor;
+class RequestStatus;
 
 class AbstractResponseFilter
 :	public RefCountable<RefCounter<ACE_NULL_SYNCH> >
@@ -38,9 +39,13 @@ class AbstractResponseFilter
 public:
 	virtual ~AbstractResponseFilter() {}
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata) = 0;
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata) = 0;
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof) = 0;
+	virtual void processBodyData(
+		RequestStatus& status,
+		SplittableBuffer& data, bool eof) = 0;
 };
 
 #endif
