@@ -61,7 +61,8 @@ AnalyzeResponseFilter::~AnalyzeResponseFilter()
 }
 
 void
-AnalyzeResponseFilter::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
+AnalyzeResponseFilter::processMetadata(
+	RequestStatus&, std::auto_ptr<HttpResponseMetadata> metadata)
 {
 	m_ptrMetadata = metadata;
 	if (m_ptrMetadata->statusLine().isRedirect()) {
@@ -82,15 +83,16 @@ AnalyzeResponseFilter::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
 }
 
 void
-AnalyzeResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
+AnalyzeResponseFilter::processBodyData(
+	RequestStatus& status, SplittableBuffer& data, bool eof)
 {
 	switch (m_state) {
 		case DELEGATING: {
-			m_ptrDelegate->processBodyData(data, eof);
+			m_ptrDelegate->processBodyData(status, data, eof);
 			break;
 		}
 		case FORWARDING: {
-			outputBodyData(data, eof);
+			outputBodyData(status, data, eof);
 			break;
 		}
 		case IDENTIFYING_CONTENT: {
@@ -112,7 +114,7 @@ AnalyzeResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
 				++it;
 			}
 			if (m_ptrDelegate.get()) {
-				startDelegating(eof);
+				startDelegating(status, eof);
 			} else if (m_candidates.empty() || eof) {
 				FilterTryList::ContentType ctype = FilterTryList::CTYPE_HTML;
 				if (FilterTryList::isHtmlFilterApplicable(getFilterChain(), *m_ptrMetadata, &ctype)) {
@@ -122,9 +124,9 @@ AnalyzeResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
 						getFilterChain().getRequestPtr(),
 						ctype == FilterTryList::CTYPE_XHTML
 					));
-					startDelegating(eof);
+					startDelegating(status, eof);
 				} else {
-					startForwarding(eof);
+					startForwarding(status, eof);
 				}
 			}
 			break;
@@ -133,17 +135,17 @@ AnalyzeResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
 }
 
 void
-AnalyzeResponseFilter::startDelegating(bool eof)
+AnalyzeResponseFilter::startDelegating(RequestStatus& status, bool eof)
 {
 	m_state = DELEGATING;
-	m_ptrDelegate->processMetadata(m_ptrMetadata);
-	m_ptrDelegate->processBodyData(m_data, eof);
+	m_ptrDelegate->processMetadata(status, m_ptrMetadata);
+	m_ptrDelegate->processBodyData(status, m_data, eof);
 }
 
 void
-AnalyzeResponseFilter::startForwarding(bool eof)
+AnalyzeResponseFilter::startForwarding(RequestStatus& status, bool eof)
 {
 	m_state = FORWARDING;
-	outputMetadata(m_ptrMetadata);
-	outputBodyData(m_data, eof);
+	outputMetadata(status, m_ptrMetadata);
+	outputBodyData(status, m_data, eof);
 }
