@@ -34,6 +34,7 @@
 
 class HttpResponseMetadata;
 class AbstractContentIdentifier;
+class RequestStatus;
 
 class AnalyzeResponseFilter : public ResponseFilterBase
 {
@@ -43,17 +44,20 @@ public:
 	
 	virtual ~AnalyzeResponseFilter();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status, SplittableBuffer& data, bool eof);
 private:
 	enum State { IDENTIFYING_CONTENT, DELEGATING, FORWARDING };
 	
 	typedef IntrusivePtr<AbstractContentIdentifier> IdentifierPtr;
 	
-	void startDelegating(bool eof);
+	void startDelegating(RequestStatus& status, bool eof);
 	
-	void startForwarding(bool eof);
+	void startForwarding(RequestStatus& status, bool eof);
 	
 	State m_state;
 	bool m_ignoreSize;
