@@ -26,12 +26,13 @@
 
 #include "NonCopyable.h"
 #include "EventHandler.h"
-#include "AsyncConnectorListener.h"
+#include "AsyncConnectorError.h"
 #include "Reactor.h"
 #include "Observer.h"
 #include "ServerReachability.h"
 #include <vector>
 
+class AsyncConnectorListener;
 class SymbolicInetAddr;
 class TimeStamp;
 class TimeDelta;
@@ -61,21 +62,21 @@ private:
 	
 	struct Error
 	{
-		typedef AsyncConnectorListener::FailureCode Code;
+		typedef AsyncConnectorError::Code Code;
 		
 		Code code;
 		int errnum;
 		
 		Error() { clear(); }
 		
-		void clear() { code = AsyncConnectorListener::FAIL_OTHER; errnum = -1; }
+		void clear() { code = AsyncConnectorError::GENERIC_ERROR; errnum = -1; }
 		
 		void set(Code code, int errnum) {
 			this->code = code; this->errnum = errnum;
 		}
 		
 		bool isSet() const {
-			return !(code == AsyncConnectorListener::FAIL_OTHER && errnum == -1);
+			return !(code == AsyncConnectorError::GENERIC_ERROR && errnum == -1);
 		}
 	};
 	
@@ -120,7 +121,7 @@ private:
 	
 	void onConnEstablished(IpRecord& ip_rec);
 	
-	void handleConnFailure(Listener::FailureCode code, int errnum);
+	void handleConnFailure(AsyncConnectorError::Code errcode, int errnum);
 	
 	SingleObserverLink<Listener> m_observerLink;
 	Error m_lastError;
