@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,16 +25,17 @@
 
 #include "types.h"
 #include "Client.h"
-#include "Server.h"
-#include "GlobalState.h"
+#include "AbstractServer.h"
 #include "HttpRequestMetadata.h"
 #include "HttpResponseMetadata.h"
 #include "HttpRequestLine.h"
 #include "RequestPtr.h"
 #include "RequestTag.h"
-#include "ErrorResponse.h"
+#include "ImmediateResponse.h"
 #include "ErrorDescriptor.h"
+#include "ErrorFactory.h"
 #include "ErrorCodes.h"
+#include "ErrorWrapper.h"
 #include "SplittableBuffer.h"
 #include "WeakPtr.h"
 #include "DataChunk.h"
@@ -42,11 +43,11 @@
 #include "AbstractDataConsumer.h"
 #include "AbstractRequestHandler.h"
 #include "AbstractResponseHandler.h"
-#include "ServiceContext.h"
 #include "HttpStreamWriter.h"
 #include "HttpMessageShaper.h"
 #include "HttpVersion.h"
 #include "TimeDelta.h"
+#include "RequestLog.h"
 #include "URI.h"
 #include "NetworkActivityReporter.h"
 #include "Debug.h"
@@ -65,19 +66,26 @@ class Client::ResponseHandler :
 	DECLARE_NON_COPYABLE(ResponseHandler)
 public:
 	ResponseHandler(
-		ClientWeakPtr const& client_ptr, ConstRequestPtr const& request,
-		RequestTag const& request_tag, long id,
+		ClientWeakPtr const& client_ptr,
+		ConstRequestPtr const& request,
+		RequestTag const& request_tag,
 		HttpStreamWriter::Connection conn_persistence);
 	
 	virtual ~ResponseHandler();
 private:
-	virtual void processProvisionalResponse(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processProvisionalResponse(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processResponseMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processResponseMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status, SplittableBuffer& data, bool eof);
 	
-	virtual void processError(IntrusivePtr<ErrorDescriptor> const& edesc);
+	virtual void processError(
+		RequestStatus& status, std::auto_ptr<ErrorDescriptor> edesc);
 	
 	virtual void processNewData(SplittableBuffer& data, bool eof);
 	
@@ -86,7 +94,6 @@ private:
 	ClientWeakPtr m_ptrClient;
 	ConstRequestPtr const m_ptrRequest;
 	RequestTag m_requestTag;
-	long const m_id;
 	bool m_isEOF;
 	uintmax_t m_producedDataSize;
 	HttpStreamWriter m_streamWriter;
@@ -109,39 +116,38 @@ private:
 };
 
 
-Client::Client(ServiceContext& context, SocketPtr const& client_stream)
-:	m_rContext(context),
-	m_ptrClientStream(client_stream),
+Client::Client(
+	SocketPtr const& client_stream,
+	AbstractServer& server, Reactor& reactor)
+:	m_ptrClientStream(client_stream),
+	m_rServer(server),
+	m_rReactor(reactor),
 	m_isEndOfOutput(false),
 	m_readTimer(
 		sigc::mem_fun(*this, &Client::onReadTimeout),
-		TimeDelta::fromSec(READ_TIMEOUT),
-		&context.reactor()
+		TimeDelta::fromSec(READ_TIMEOUT), &reactor
 	),
 	m_writeTimer(
 		sigc::mem_fun(*this, &Client::onWriteTimeout),
-		TimeDelta::fromSec(WRITE_TIMEOUT),
-		&context.reactor()
+		TimeDelta::fromSec(WRITE_TIMEOUT), &reactor
 	),
 	m_idleTimer(
 		sigc::mem_fun(*this, &Client::onIdleTimeout),
-		TimeDelta::fromSec(IDLE_TIMEOUT),
-		&context.reactor()
+		TimeDelta::fromSec(IDLE_TIMEOUT), &reactor
 	),
 	m_eventMask(Reactor::READ),
 	m_flags(0),
 	m_isWaitingForWrite(0),
-	m_responseIdCounter(0),
-	m_lastResponseToProduceOutput(-1),
 	m_ptrSelf(this)
 {
 	DBG_CLIENT_CONNECTION_BEGIN();
 	m_ptrClientStream->enable(ACE_NONBLOCK);
 	
-	Reactor& reactor = m_rContext.reactor();
-	reactor.beforeSleepSignal().connect(sigc::mem_fun(*this, &Client::updateState));
+	m_rReactor.beforeSleepSignal().connect(
+		sigc::mem_fun(*this, &Client::updateState)
+	);
 	try {
-		m_handlerId = reactor.registerHandler(
+		m_handlerId = m_rReactor.registerHandler(
 			m_ptrClientStream->get_handle(),
 			IntrusivePtr<EventHandlerBase>(this),
 			m_eventMask
@@ -155,7 +161,7 @@ Client::Client(ServiceContext& context, SocketPtr const& client_stream)
 Client::~Client()
 {
 	if (m_handlerId) {
-		m_rContext.reactor().unregisterHandler(m_handlerId);
+		m_rReactor.unregisterHandler(m_handlerId);
 	}
 	DBG_CLIENT_CONNECTION_END();
 }
@@ -200,6 +206,9 @@ Client::writeOutputData()
 #else
 		m_outputData.trimFront(sent);
 #endif
+		if (m_outputData.empty()) {
+			m_ptrLastOutputWriter.reset(0);
+		}
 		return sent;
 	} else {
 		DEBUGLOG("ERROR writing to client");
@@ -243,24 +252,20 @@ Client::processInputData(bool eof)
 			m_ptrRequestHandler.reset(0);
 			m_ptrRequestURI.reset(0);
 		} else if (status == ERROR_STATE) {
-			DBG_INCOMING_REQUEST_ERROR();
 			//DEBUGLOG("ERROR parsing request");
-			IntrusivePtr<ErrorDescriptor> edesc(errorDescriptor());
+			std::auto_ptr<ErrorDescriptor> edesc(retrieveErrorDescriptor());
 			if (!edesc.get()) {
-				edesc.reset(new ErrorDescriptor(
+				edesc = ErrorFactory::errParsingRequest(
 					ErrorCodes::ERROR_PARSING_RESPONSE,
 					"error parsing request: "+errorMessage(),
-					sigc::bind(
-						sigc::ptr_fun(&ErrorResponse::errParsingRequest),
-						m_ptrRequestURI.get() ? m_ptrRequestURI->toString() : string(),
-						errorMessage()
-					)
-				));
+					m_ptrRequestURI.get() ? *m_ptrRequestURI : URI(BString()),
+					errorMessage()
+				);
 			}
 			
 			if (m_ptrRequestHandler.get()) {
 				// the error happened after we've received the metadata
-				m_ptrRequestHandler->cancelRequest(edesc);
+				m_ptrRequestHandler->cancel(edesc);
 				m_ptrRequestHandler.reset(0);
 				m_ptrRequestURI.reset(0);
 			} else {
@@ -268,24 +273,36 @@ Client::processInputData(bool eof)
 					// an eof while in RequestStart state generates an error
 					break;
 				}
-				// The error happened before we've received the metadata.
-				// We make up a request and submit it with an error response attached.
-				HttpRequestLine rline(BString("GET"), URI(BString()), HttpVersion::HTTP_1_0);
+				// We don't have request metadata, as the error happened
+				// too early. We synthesize a dummy request and submit it
+				// with an error response attached.
+				HttpRequestLine const rline(
+					BString("GET"),
+					URI(BString("<broken request>")),
+					HttpVersion::HTTP_1_0
+				);
 				RequestPtr request(new HttpRequestMetadata(rline));
 				request->setBodyStatus(HttpRequestMetadata::BODY_FORBIDDEN);
+				
 				RequestTag request_tag;
+				
+				DBG_REGISTER_CLIENT_REQUEST(*request, request_tag);
+				DBG_INCOMING_REQUEST_BEGIN(*request, request_tag);
+				
 				IntrusivePtr<ResponseHandler> response_handler(
 					new ResponseHandler(
 						m_ptrSelf, request, request_tag,
-						++m_responseIdCounter,
 						HttpStreamWriter::CONN_CLOSE
 					)
 				);
+				
 				ScopedSuspender suspender(*this);
+				
 				IntrusivePtr<AbstractRequestHandler> request_handler(
-					m_rContext.server().submitRequest(
+					m_rServer.submitRequest(
 						request, request_tag,
-						response_handler, edesc
+						response_handler,
+						ErrorWrapper::wrap(edesc)
 					)
 				);
 				SplittableBuffer body_data;
@@ -295,6 +312,7 @@ Client::processInputData(bool eof)
 				request_handler->appendBodyData(body_data, true);
 			}
 			
+			DBG_INCOMING_REQUEST_ERROR();
 			switchToInactive();
 			m_flags |= READING_FORBIDDEN;
 			m_inputData.clear();
@@ -309,20 +327,25 @@ Client::processInputData(bool eof)
 }
 
 void
-Client::processResponseData(SplittableBuffer& data, bool eof, long response_id)
+Client::processResponseData(
+	SplittableBuffer& data, bool const eof,
+	IntrusivePtr<ResponseHandler> const& response_handler)
 {
 	if (m_isEndOfOutput || isSessionTerminationScheduled()) {
 		data.clear();
 		return;
 	}
-	m_lastResponseToProduceOutput = response_id;
+	
+	if (!data.empty()) {
+		m_outputData.appendDestructive(data);
+		m_ptrLastOutputWriter = response_handler;
+	}
 	m_isEndOfOutput = eof;
-	m_outputData.appendDestructive(data);
 	
 	if (m_outputData.size() > MAX_WRITE_BUF_SIZE) {
 		ScopedIncDec<int> flag_manager(m_isWaitingForWrite);
 		while (!m_outputData.empty()) {
-			if (m_rContext.reactor().handleEvents() != Reactor::SUCCESS) {
+			if (m_rReactor.handleEvents() != Reactor::SUCCESS) {
 				break;
 			}
 		}
@@ -330,15 +353,22 @@ Client::processResponseData(SplittableBuffer& data, bool eof, long response_id)
 }
 
 bool
-Client::tryDiscardResponseOutput(long response_id, uintmax_t discard_size)
+Client::tryDiscardResponseOutput(
+	ResponseHandler const& response_handler,
+	uintmax_t const discard_size)
 {
-	if (response_id != m_lastResponseToProduceOutput) {
+	if (&response_handler !=  m_ptrLastOutputWriter.get()) {
 		return false;
 	}
 	if (discard_size > m_outputData.size()) {
 		return false;
 	}
+	
 	m_outputData.trimBack(discard_size);
+	if (m_outputData.empty()) {
+		m_ptrLastOutputWriter.reset(0);
+	}
+	
 	return true;
 }
 
@@ -352,8 +382,7 @@ bool
 Client::isIdle() const
 {
 	return (m_outputData.empty() && !isResponseInProgress() &&
-		m_rContext.server().getNumPendingRequests() == 0 &&
-		!isRequestInProgress());
+		m_rServer.isIdle() && !isRequestInProgress());
 }
 
 void
@@ -385,9 +414,9 @@ Client::terminateSession()
 	m_idleTimer.deactivate();
 	m_eventMask = Reactor::NO_EVENTS;
 	if (m_handlerId) {
-		m_rContext.reactor().setEvents(m_handlerId, m_eventMask);
+		m_rReactor.setEvents(m_handlerId, m_eventMask);
 	}
-	m_rContext.reactor().stop();
+	m_rReactor.stop();
 }
 
 void
@@ -407,7 +436,9 @@ Client::updateState()
 		// necessary on the edge-triggered WFMOReactor
 		processOutputData(); // can schedule session termination
 	}
-	if (m_rContext.server().getNumPendingRequests() == 0 && isReadingForbidden()) {
+	if (m_rServer.isIdle() && isReadingForbidden()) {
+		// This takes care of a situation when parse error happened
+		// after submitting the request to the server.
 		m_isEndOfOutput = true;
 	}
 	if (m_outputData.empty() && m_isEndOfOutput) {
@@ -421,8 +452,7 @@ Client::updateState()
 	Reactor::IOEvents mask = m_eventMask;
 	
 	if (m_flags & (READING_FORBIDDEN|READING_SUSPENDED) ||
-	    m_rContext.server().getNumPendingRequests() >=
-		m_rContext.server().getMaxPendingRequests()) {
+	    m_rServer.isOverloaded()) {
 		mask &= ~Reactor::READ;
 	} else {
 		mask |= Reactor::READ;
@@ -433,7 +463,7 @@ Client::updateState()
 	} else {
 		mask &= ~Reactor::WRITE;
 		if (m_isWaitingForWrite) {
-			m_rContext.reactor().wakeup();
+			m_rReactor.wakeup();
 		}
 		
 		m_flags &= ~WRITE_BUFFER_FULL;
@@ -458,7 +488,7 @@ Client::updateState()
 	}
 	
 	if (mask != m_eventMask) {
-		m_rContext.reactor().setEvents(m_handlerId, mask);
+		m_rReactor.setEvents(m_handlerId, mask);
 		m_eventMask = mask;
 	}
 }
@@ -468,25 +498,25 @@ Client::eventGotMetadata(auto_ptr<HttpRequestMetadata> metadata, bool is_persist
 {
 	m_ptrRequestURI.reset(new URI(metadata->requestLine().getURI()));
 	
-	DBG_REGISTER_CLIENT_REQUEST(*metadata);
-	DBG_INCOMING_REQUEST_BEGIN(*metadata);
+	RequestTag request_tag;
 	
-	HttpMessageShaper::shapeRequest(*metadata);
+	DBG_REGISTER_CLIENT_REQUEST(*metadata, request_tag);
+	DBG_INCOMING_REQUEST_BEGIN(*metadata, request_tag);
+	
+	HttpMessageShaper::prepareForForwarding(*metadata);
 	
 	ConstRequestPtr request(metadata.release());
 	// metadata is null now !!!
 	
-	RequestTag request_tag;
 	IntrusivePtr<ResponseHandler> response_handler(
 		new ResponseHandler(
 			m_ptrSelf, request, request_tag,
-			++m_responseIdCounter,
 			is_persistent ? HttpStreamWriter::CONN_KEEP_ALIVE
 			: HttpStreamWriter::CONN_CLOSE
 		)
 	);
 	ScopedSuspender suspender(*this);
-	m_ptrRequestHandler = m_rContext.server().submitRequest(
+	m_ptrRequestHandler = m_rServer.submitRequest(
  		request, request_tag, response_handler
 	);
 }
@@ -545,12 +575,11 @@ Client::handleWrite(ACE_HANDLE)
 
 Client::ResponseHandler::ResponseHandler(
 	ClientWeakPtr const& client_ptr, ConstRequestPtr const& request,
-	RequestTag const& request_tag, long id,
+	RequestTag const& request_tag,
 	HttpStreamWriter::Connection conn_persistence)
 :	m_ptrClient(client_ptr),
 	m_ptrRequest(request),
 	m_requestTag(request_tag),
-	m_id(id),
 	m_isEOF(false),
 	m_producedDataSize(0),
 	m_streamWriter(*this),
@@ -563,8 +592,16 @@ Client::ResponseHandler::~ResponseHandler()
 }
 
 void
-Client::ResponseHandler::processProvisionalResponse(std::auto_ptr<HttpResponseMetadata> metadata)
+Client::ResponseHandler::processProvisionalResponse(
+	RequestStatus&, std::auto_ptr<HttpResponseMetadata> metadata)
 {
+#ifdef DEBUG
+	metadata->headers().setHeader(
+		BString("X-Request-URI"),
+		m_ptrRequest->requestLine().getURI().toBString()
+	);
+#endif
+	
 	if (m_ptrRequest->requestLine().getHttpVersion() >= HttpVersion::HTTP_1_1) {
 		m_streamWriter.startResponse(
 			*metadata, m_ptrRequest->requestLine(),
@@ -576,8 +613,16 @@ Client::ResponseHandler::processProvisionalResponse(std::auto_ptr<HttpResponseMe
 }
 
 void
-Client::ResponseHandler::processResponseMetadata(std::auto_ptr<HttpResponseMetadata> metadata)
+Client::ResponseHandler::processResponseMetadata(
+	RequestStatus&, std::auto_ptr<HttpResponseMetadata> metadata)
 {
+#ifdef DEBUG
+	metadata->headers().setHeader(
+		BString("X-Request-URI"),
+		m_ptrRequest->requestLine().getURI().toBString()
+	);
+#endif
+	
 	if (Client* client = m_ptrClient.get()) {
 		client->setResponseInProgress(true);
 	}
@@ -591,19 +636,20 @@ Client::ResponseHandler::processResponseMetadata(std::auto_ptr<HttpResponseMetad
 	typedef AbstractDebugAgent ADA;
 	ADA::HttpMessageType msg_type = ADA::UNMODIFIED_OUTGOING_RESPONSE;
 	int const scode = metadata->statusLine().getCode();
-	if (m_requestTag->flags().isSet(RequestTag::RESPONSE_CRAFTED)) {
-		msg_type = ADA::CRAFTED_OUTGOING_RESPONSE;
-	} else if (scode >= 400 && scode < 600) {
+	if (scode >= 400 && scode < 600) {
 		msg_type = ADA::ERROR_OUTGOING_RESPONSE;
+	} else if (m_requestTag->flags().isSet(RequestTag::RESPONSE_CRAFTED)) {
+		msg_type = ADA::CRAFTED_OUTGOING_RESPONSE;
 	} else if (m_requestTag->flags().isSet(RequestTag::RESPONSE_MODIFIED)) {
 		msg_type = ADA::FILTERED_OUTGOING_RESPONSE;
 	}
-	DBG_HTTP_MESSAGE_BEGIN(*metadata, msg_type);
+	DBG_HTTP_MESSAGE_BEGIN(*metadata, m_requestTag, msg_type);
 #endif
 }
 
 void
-Client::ResponseHandler::processBodyData(SplittableBuffer& data, bool eof)
+Client::ResponseHandler::processBodyData(
+	RequestStatus&, SplittableBuffer& data, bool eof)
 {
 	if (m_isEOF) {
 		data.clear();
@@ -617,13 +663,15 @@ Client::ResponseHandler::processBodyData(SplittableBuffer& data, bool eof)
 }
 
 void
-Client::ResponseHandler::processError(IntrusivePtr<ErrorDescriptor> const& edesc)
+Client::ResponseHandler::processError(
+	RequestStatus& status, std::auto_ptr<ErrorDescriptor> edesc)
 {
 	DEBUGLOG(
 		"Client::ResponseHandler::processError(): "
-		<< edesc->getErrorMessage() << "\r\nURL: "
+		<< edesc->getDebugMessage() << "\r\nURL: "
 		<< m_ptrRequest->requestLine().getURI()
 	);
+	
 	if (edesc->getErrorCode() == ErrorCodes::ERROR_DECOMPRESSING_RESPONSE) {
 		// Some sites actually produce broken compressed content,
 		// but browsers display it correctly, because the error
@@ -640,33 +688,7 @@ Client::ResponseHandler::processError(IntrusivePtr<ErrorDescriptor> const& edesc
 		// ignore errors that come after EOF
 		// that could be a REQUEST_CANCEL_TO_SAVE_TRAFFIC error
 	} else if (m_producedDataSize == 0 || tryDiscardOutput()) {
-		DBG_OUTGOING_RESPONSE_ERROR();
-		m_streamWriter.reset();
-		if (Client* client = m_ptrClient.get()) {
-			if (client->isReadingForbidden()) {
-				m_connPersistence = HttpStreamWriter::CONN_CLOSE;
-			}
-		}
-		auto_ptr<CraftedResponse> response = edesc->responseGenerator()();
-		response->metadata().setClientRequestId(m_ptrRequest->getClientRequestId());
-#ifdef DEBUG
-		response->metadata().headers().setHeader(
-			BString("X-Request-URI"),
-			m_ptrRequest->requestLine().getURI().toBString()
-		);
-#endif
-		if (m_ptrRequest->requestLine().getMethod() == BString("HEAD")) {
-			response->metadata().setBodyStatus(HttpResponseMetadata::BODY_FORBIDDEN);
-			response->body().clear();
-		}
-		
-		m_streamWriter.startResponse(
-			response->metadata(), m_ptrRequest->requestLine(),
-			m_connPersistence
-		);
-		DBG_ERROR_OUTGOING_RESPONSE_BEGIN(response->metadata());
-		m_streamWriter.appendBodyData(response->body(), true);
-		DBG_OUTGOING_RESPONSE_END();
+		edesc->retrieveResponse()->output(*this, m_ptrRequest, status, m_requestTag);
 	} else {
 		//DEBUGLOG("some part of the response has already made its way to the client");
 		DBG_OUTGOING_RESPONSE_ERROR();
@@ -684,9 +706,11 @@ Client::ResponseHandler::processNewData(SplittableBuffer& data, bool eof)
 	if (Client* client = m_ptrClient.get()) {
 		bool stream_eof = eof && (
 			m_connPersistence == HttpStreamWriter::CONN_CLOSE
-			|| client->isReadingForbidden()
 		);
-		client->processResponseData(data, stream_eof, m_id);
+		client->processResponseData(
+			data, stream_eof,
+			IntrusivePtr<ResponseHandler>(this)
+		);
 		if (eof) {
 			client->setResponseInProgress(false);
 		}
@@ -697,7 +721,7 @@ bool
 Client::ResponseHandler::tryDiscardOutput()
 {
 	if (Client* client = m_ptrClient.get()) {
-		if (client->tryDiscardResponseOutput(m_id, m_producedDataSize)) {
+		if (client->tryDiscardResponseOutput(*this, m_producedDataSize)) {
 			m_producedDataSize = 0;
 			return true;
 		}
