@@ -29,20 +29,20 @@
 #include "IntrusivePtr.h"
 #include "ReactorFactory.h"
 #include "SynchFactory.h"
-#include "InetAddr.h"
 #include "RefCountableSAP.h"
 #include "ServerConnectionPool.h"
 #include <ace/config-lite.h>
 #include <ace/SOCK_Acceptor.h>
 #include <ace/SOCK_Stream.h>
+#include <ace/INET_Addr.h>
 #include <ace/Time_Value.h>
 
 using namespace std;
 
-class ConnAcceptor::EH : public EventHandler<RefCounter<ACE_MT_SYNCH> >
+class ConnAcceptor::EvtHandler : public EventHandler<RefCounter<ACE_MT_SYNCH> >
 {
 public:
-	EH(ConnAcceptor& owner, AcceptorPtr const& acceptor);
+	EvtHandler(ConnAcceptor& owner, AcceptorPtr const& acceptor);
 private:
 	virtual void handleRead(ACE_HANDLE);
 	
@@ -51,10 +51,20 @@ private:
 };
 
 
-ConnAcceptor::ConnAcceptor(bool stop_on_signals)
+class ConnAcceptor::AcceptorReadyException
+{
+public:
+	AcceptorPtr acceptor;
+	
+	AcceptorReadyException(AcceptorPtr acceptor) : acceptor(acceptor) {}
+};
+
+
+ConnAcceptor::ConnAcceptor(StopOnSignals stop_on_signals)
 {
 	m_ptrReactor = ReactorFactory::createBestReactor(
-		SynchFactory<ACE_MT_SYNCH>(), stop_on_signals
+		SynchFactory<ACE_MT_SYNCH>(),
+		stop_on_signals == STOP_ON_SIGNALS
 	);
 	
 	/*
@@ -71,7 +81,7 @@ ConnAcceptor::~ConnAcceptor()
 bool
 ConnAcceptor::add(AcceptorPtr const& acceptor)
 {
-	Reactor::EventHandlerPtr handler(new EH(*this, acceptor));
+	Reactor::EventHandlerPtr handler(new EvtHandler(*this, acceptor));
 	try {
 		m_ptrReactor->registerHandler(
 			acceptor->get_handle(), handler, Reactor::READ
@@ -97,41 +107,75 @@ ConnAcceptor::removeAll()
 	m_ptrReactor->unregisterAllHandlers();
 }
 
-int
-ConnAcceptor::acceptConnections()
+ConnAcceptor::Status
+ConnAcceptor::accept(ACE_SOCK_Stream& peer, ACE_INET_Addr& peer_addr)
 {
-	m_ptrReactor->restart(); // in case we have been forceStop()'ed
-	return m_ptrReactor->runEventLoop();
+	Reactor::Status status = Reactor::SUCCESS;
+	do {
+		try {
+			status = m_ptrReactor->runEventLoop();
+		} catch (AcceptorReadyException const& e) {
+			return acceptConnection(e.acceptor, peer, peer_addr);
+		}
+	} while (status == Reactor::SUCCESS);
+	
+	if (status == Reactor::STOPPED) {
+		m_ptrReactor->restart();
+		return ABORTED;
+	} else if (status == Reactor::INTERRUPTED) {
+		return STOPPED_BY_SIGNAL;
+	} else {
+		return FAILED;
+	}
 }
 
 void
-ConnAcceptor::forceStop()
+ConnAcceptor::abort()
 {
 	m_ptrReactor->stop();
 }
 
+ConnAcceptor::Status
+ConnAcceptor::acceptConnection(
+	AcceptorPtr const& acceptor,
+	ACE_SOCK_Stream& peer, ACE_INET_Addr& peer_addr)
+{
+	ACE_Time_Value timeout;
+	int const restart = 0; // don't retry on EINTR
+	int const reset_new_handle = 1; // call WSAEventSelect(h, 0, 0);
+	int const res = acceptor->accept(
+		peer, &peer_addr, &timeout, restart, reset_new_handle
+	);
+	if (res == 0) {
+		return ACCEPTED;
+	} else {
+		return FAILED;
+	}
+}
 
-/*======================= ConnAcceptor::EH =========================*/
 
-ConnAcceptor::EH::EH(ConnAcceptor& owner, AcceptorPtr const& acceptor)
+/*===================== ConnAcceptor::EvtHandler =======================*/
+
+ConnAcceptor::EvtHandler::EvtHandler(
+	ConnAcceptor& owner, AcceptorPtr const& acceptor)
 :	m_rOwner(owner),
 	m_ptrAcceptor(acceptor)
 {
 }
 
 void
-ConnAcceptor::EH::handleRead(ACE_HANDLE)
+ConnAcceptor::EvtHandler::handleRead(ACE_HANDLE)
 {
-	typedef IntrusivePtr<RefCountableSAP<ACE_SOCK_Stream> > SocketPtr;
-	SocketPtr sock(new RefCountableSAP<ACE_SOCK_Stream>);
-	InetAddr client_addr;
-	ACE_Time_Value timeout(ACE_Time_Value::zero);
-	int const restart = 0; // don't retry on EINTR
-	int const reset_new_handle = 1; // call WSAEventSelect(h, 0, 0);
-	int const res = m_ptrAcceptor->accept(
-		*sock, &client_addr, &timeout, restart, reset_new_handle
-	);
-	if (res == 0) {
-		m_rOwner.workerPool().handleConnection(sock, client_addr);
-	}
+	throw AcceptorReadyException(m_ptrAcceptor);
+	/*
+	We just have to throw an exception here.
+	Consider what happens in case of the edge-triggered WFMOReactor:
+	If WaitForMultipleObjects() indicates that several handles are ready,
+	several event handlers will be dispatched.  But we need only one
+	of them!  If we ignore the rest, we won't get any more notifications
+	on them (notice the edge-triggered behaviour).
+	Also, we can't use Reactor::stop(), as it's asynchronous, so it
+	won't stop the reactor immediately.
+	Fortunately, Reactor was designed to be completely exception-safe.
+	*/
 }
