@@ -27,9 +27,10 @@
 #include "ResponseFilterBase.h"
 #include "NonCopyable.h"
 #include <string>
+#include <memory>
 
 class AbstractDecompressor;
-class ResponseErrorInitiator;
+class RequestStatus;
 class HttpResponseMetadata;
 class HttpHeader;
 class BString;
@@ -42,15 +43,19 @@ public:
 	
 	virtual ~DecompressorResponseFilter();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status,
+		SplittableBuffer& data, bool eof);
 	
 	static bool isSupported(BString const& compression);
 private:
 	enum { OUTPUT_LIMIT = 16384 };
 	
-	typedef AbstractDecompressor* (*DescriptorConstructor)();
+	typedef std::auto_ptr<AbstractDecompressor> (*DescriptorConstructor)();
 	
 	struct DecompressorDescriptor
 	{
@@ -60,9 +65,9 @@ private:
 	
 	static DecompressorDescriptor const* findDescriptor(BString const& decompressor);
 	
-	static AbstractDecompressor* createGzipDecompressor();
+	static std::auto_ptr<AbstractDecompressor> createGzipDecompressor();
 	
-	static AbstractDecompressor* createDeflateDecompressor();
+	static std::auto_ptr<AbstractDecompressor> createDeflateDecompressor();
 	
 	void setupDecompressor(HttpResponseMetadata& metadata, HttpHeader* hdr);
 	
