@@ -34,6 +34,7 @@
 class HttpResponseMetadata;
 class SplittableBuffer;
 class ErrorDescriptor;
+class RequestStatus;
 
 class DownloadSizeLimiter : public ResponseFilterBase
 {
@@ -43,11 +44,14 @@ public:
 	
 	virtual ~DownloadSizeLimiter();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status, SplittableBuffer& data, bool eof);
 private:
-	void raiseError();
+	void cancelRequest(RequestStatus& status);
 	
 	uintmax_t m_sizeLimit;
 };
