@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 namespace ErrorCodes
 {
-	enum {
+	enum Code {
 		UNKNOWN_ERROR,
 		ERROR_PARSING_REQUEST,
 		ERROR_PARSING_RESPONSE,
@@ -40,6 +40,7 @@ namespace ErrorCodes
 		REQUEST_BODY_TOO_BIG, // when using chunked requests (we have to buffer them)
 		ERROR_COMPRESSING_RESPONSE,
 		ERROR_DECOMPRESSING_RESPONSE,
+		ERROR_READING_CACHED_RESPONSE,
 		TOO_MANY_REDIRECTS,    //
 		RESPONSE_BODY_TOO_BIG, //
 		WRONG_RESPONSE_STATUS, // } when fetching external scripts
@@ -47,7 +48,8 @@ namespace ErrorCodes
 		REQUEST_CANCEL_TO_SAVE_TRAFFIC, // used by response analyzers
 		REMOTE_PROXY_CONFIG_PROBLEM,
 		ERROR_FORWARDING_THROUGH_PROXY,
-		TUNNEL_PORT_NOT_ALLOWED
+		TUNNEL_PORT_NOT_ALLOWED,
+		URL_FORBIDDEN
 	};
 }
 
