@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,34 +24,14 @@
 #endif
 
 #include "ErrorDescriptor.h"
-#include "ErrorResponse.h"
-
-using namespace std;
+#include "ImmediateResponse.h"
 
 ErrorDescriptor::ErrorDescriptor(
-	int code, string const& message, CraftedResponseGenerator const& generator)
+	ErrorCodes::Code const code, std::string const& debug_msg,
+	std::auto_ptr<ImmediateResponse> response)
 :	m_errorCode(code),
-	m_errorMessage(message),
-	m_responseGenerator(generator)
-{
-}
-
-ErrorDescriptor::ErrorDescriptor(CraftedResponseGenerator const& generator)
-:	m_errorCode(ErrorCodes::UNKNOWN_ERROR),
-	m_responseGenerator(generator)
-{
-}
-
-ErrorDescriptor::ErrorDescriptor(int code, std::string const& message)
-:	m_errorCode(code),
-	m_errorMessage(message),
-	m_responseGenerator(sigc::ptr_fun(&ErrorResponse::errDummyError))
-{
-}
-
-ErrorDescriptor::ErrorDescriptor(int code)
-:	m_errorCode(code),
-	m_responseGenerator(sigc::ptr_fun(&ErrorResponse::errDummyError))
+	m_debugMessage(debug_msg),
+	m_ptrResponse(response)
 {
 }
 
