@@ -32,6 +32,7 @@
 
 class HttpResponseMetadata;
 class ErrorDescriptor;
+class RequestStatus;
 
 class FlashResponseFilter : public ResponseFilterBase
 {
@@ -41,17 +42,20 @@ public:
 	
 	virtual ~FlashResponseFilter();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status, SplittableBuffer& data, bool eof);
 private:
 	enum State { INSPECTING, FORWARDING, SUBSTITUTING };
 	
 	bool isAd();
 	
-	void outputAdSubstitution();
+	void outputAdSubstitution(RequestStatus& status);
 	
-	void considerRequestCancel();
+	void considerRequestCancel(RequestStatus& status);
 	
 	State m_state;
 	bool m_ignoreSize;
