@@ -69,7 +69,10 @@ struct HeuristicScore::SizeRecordComparator
 
 HeuristicScore::SizeRecord const HeuristicScore::m_sCommonSizes[] = {
 	// sorted by width, height
+	{ 80,  31,  true, 80  },
+	{ 80,  80,  false, 30 },
 	{ 88,  31,  true, 80  },
+	{ 94,  15,  true, 100 },
 	{ 100, 100, false, 30 },
 	{ 120, 60,  true, 100 },
 	{ 120, 90,  false, 30 },
@@ -78,18 +81,39 @@ HeuristicScore::SizeRecord const HeuristicScore::m_sCommonSizes[] = {
 	{ 120, 300, true, 120 },
 	{ 120, 600, true, 120 },
 	{ 125, 125, false, 30 },
+	{ 130, 80,  true, 120 },
+	{ 137, 60,  true, 120 },
+	{ 137, 600, true, 120 },
+	{ 150, 200, true, 80  },
+	{ 156, 60,  true, 120 },
 	{ 160, 600, true, 120 },
 	{ 180, 150, true, 100 },
 	{ 200, 600, true, 80  },
+	{ 230, 33,  true, 120 },
 	{ 234, 60,  true, 120 },
 	{ 234, 120, true, 120 },
 	{ 240, 400, true, 120 },
 	{ 250, 250, false, 30 },
 	{ 300, 250, false, 30 },
+	{ 300, 600, true, 100 },
 	{ 336, 280, true, 120 },
+	{ 400, 400, false, 30 },
+	{ 457, 60,  true, 120 },
+	{ 465, 62,  true, 120 },
 	{ 468, 60,  true, 120 },
+	{ 468, 70,  true, 120 },
 	{ 468, 80,  true, 120 },
-	{ 728, 90,  true, 120 }
+	{ 468, 90,  true, 120 },
+	{ 468, 100, true, 120 },
+	{ 468, 120, true, 120 },
+	{ 468, 150, true, 120 },
+	{ 500, 350, false, 30 },
+	{ 550, 480, false, 30 },
+	{ 700, 500, false, 30 },
+	{ 720, 300, true, 120 },
+	{ 728, 90,  true, 120 },
+	{ 728, 210, true, 120 },
+	{ 750, 150, true, 120 }
 };
 
 
