@@ -44,7 +44,8 @@ HtmlContentValidator::~HtmlContentValidator()
 }
 
 void
-HtmlContentValidator::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
+HtmlContentValidator::processMetadata(
+	RequestStatus&, std::auto_ptr<HttpResponseMetadata> metadata)
 {
 	// Content-Type is checked in FilterTryList::tryHtmlContentValidator()
 	m_ptrMetadata = metadata;
@@ -54,10 +55,11 @@ HtmlContentValidator::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
 }
 
 void
-HtmlContentValidator::processBodyData(SplittableBuffer& data, bool eof)
+HtmlContentValidator::processBodyData(
+	RequestStatus& status, SplittableBuffer& data, bool eof)
 {
 	if (!m_ptrMetadata.get()) {
-		outputBodyData(data, eof);
+		outputBodyData(status, data, eof);
 		return;
 	}
 	
@@ -65,8 +67,8 @@ HtmlContentValidator::processBodyData(SplittableBuffer& data, bool eof)
 		if (!data.empty() && *data.begin() == '<') {
 			// optimize for common case
 			setFlags();
-			outputMetadata(m_ptrMetadata);
-			outputBodyData(data, eof);
+			outputMetadata(status, m_ptrMetadata);
+			outputBodyData(status, data, eof);
 			return;
 		}
 		
@@ -74,21 +76,20 @@ HtmlContentValidator::processBodyData(SplittableBuffer& data, bool eof)
 	}
 	
 	m_ptrHtmlDetector->consume(data, eof);
-	HtmlDetector::Status status = m_ptrHtmlDetector->getStatus();
-	switch (status) {
+	switch (m_ptrHtmlDetector->getStatus()) {
 		case HtmlDetector::IN_PROGRESS: {
 			if (m_ptrHtmlDetector->bufferedData().size() > MAX_BUFFERED_SIZE) {
-				onResult(true, eof);
+				onResult(status, true, eof);
 			}
 			break;
 		}
 		case HtmlDetector::HTML_DETECTED:
 		case HtmlDetector::EMPTY_DOC: {
-			onResult(true, eof);
+			onResult(status, true, eof);
 			break;
 		}
 		case HtmlDetector::HTML_NOT_DETECTED: {
-			onResult(false, eof);
+			onResult(status, false, eof);
 			break;
 		}
 	}
@@ -103,7 +104,7 @@ HtmlContentValidator::setFlags()
 }
 
 void
-HtmlContentValidator::onResult(bool detected, bool eof)
+HtmlContentValidator::onResult(RequestStatus& status, bool detected, bool eof)
 {
 	if (detected) {
 		setFlags();
@@ -111,6 +112,6 @@ HtmlContentValidator::onResult(bool detected, bool eof)
 	SplittableBuffer data;
 	m_ptrHtmlDetector->reset(data);
 	m_ptrHtmlDetector.reset(0);
-	outputMetadata(m_ptrMetadata);
-	outputBodyData(data, eof);
+	outputMetadata(status, m_ptrMetadata);
+	outputBodyData(status, data, eof);
 }
