@@ -32,6 +32,7 @@
 class HttpResponseMetadata;
 class ResponseFilterChain;
 class HtmlDetector;
+class RequestStatus;
 
 class HtmlContentValidator : public ResponseFilterBase
 {
@@ -41,15 +42,19 @@ public:
 	
 	virtual ~HtmlContentValidator();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status,
+		SplittableBuffer& data, bool eof);
 private:
 	enum { MAX_BUFFERED_SIZE = 1024 };
 	
 	void setFlags();
 	
-	void onResult(bool detected, bool eof);
+	void onResult(RequestStatus& status, bool detected, bool eof);
 	
 	std::auto_ptr<HttpResponseMetadata> m_ptrMetadata;
 	std::auto_ptr<HtmlDetector> m_ptrHtmlDetector;
