@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 class HtmlProcessor;
 class ResponseErrorInitiator;
 class HttpResponseMetadata;
+class RequestStatus;
 
 class HtmlResponseFilter : public ResponseFilterBase
 {
@@ -44,9 +45,13 @@ public:
 	
 	virtual ~HtmlResponseFilter();
 	
-	void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status,
+		SplittableBuffer& data, bool eof);
 private:
 	HtmlProcessor& m_rProcessor;
 };
