@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,14 +27,17 @@
 #include "NonCopyable.h"
 #include "SplittableBuffer.h"
 #include "IntrusivePtr.h"
+#include "StrongPtr.h"
 #include "RequestPtr.h"
 #include <stddef.h>
 #include <limits>
 #include <memory>
 
-class Server;
+class ServiceContext;
+class AbstractServer;
 class AbstractRequestHandler;
 class HttpResponseMetadata;
+class RequestTag;
 class ErrorDescriptor;
 class ResponseFilterChain;
 class FilterTryList;
@@ -45,7 +48,9 @@ class HttpFetcher
 public:
 	enum Status { IN_PROGRESS, COMPLETE, FAILED };
 	
-	HttpFetcher(Server& server, ConstRequestPtr const& request,
+	HttpFetcher(
+		ServiceContext& context, AbstractServer& server,
+		ConstRequestPtr const& request, RequestTag const& request_tag,
 		size_t max_body_size = std::numeric_limits<size_t>::max(),
 		size_t max_fetch_size = std::numeric_limits<size_t>::max());
 	// The body may be decompressed while being received, so max_body_size
@@ -65,9 +70,9 @@ public:
 	
 	size_t getReceivedBodySize() const { return m_receivedBodySize; }
 	
-	IntrusivePtr<ErrorDescriptor>& errorDescriptor() { return m_ptrErrDesc; }
+	std::auto_ptr<ErrorDescriptor> const& errorDescriptor() const { return m_ptrErrDesc; }
 	
-	IntrusivePtr<ErrorDescriptor> const& errorDescriptor() const { return m_ptrErrDesc; }
+	std::auto_ptr<ErrorDescriptor> retrieveErrorDescriptor() { return m_ptrErrDesc; }
 private:
 	class ResponseHandler;
 	friend class HttpFetcher::ResponseHandler;
@@ -76,15 +81,16 @@ private:
 	
 	void handleData(SplittableBuffer& data, bool eof);
 	
-	void handleError(IntrusivePtr<ErrorDescriptor> const& edesc);
+	void handleError(std::auto_ptr<ErrorDescriptor> edesc);
 	
 	static void createSizeLimiterFilter(
 		ResponseFilterChain& chain,
 		HttpResponseMetadata const& metadata, size_t limit);
 	
-	Server& m_rServer;
+	StrongPtr<ACE_NULL_SYNCH, HttpFetcher, HttpFetcher*> m_ptrSelf;
+	ServiceContext& m_rContext;
+	AbstractServer& m_rServer;
 	ConstRequestPtr m_ptrRequest;
-	IntrusivePtr<ResponseHandler> m_ptrResponseHandler;
 	IntrusivePtr<AbstractRequestHandler> m_ptrRequestHandler;
 	Status m_status;
 	size_t m_maxBodySize;
@@ -92,7 +98,7 @@ private:
 	size_t m_receivedBodySize;
 	SplittableBuffer m_responseBody;
 	std::auto_ptr<HttpResponseMetadata> m_ptrResponseMetadata;
-	IntrusivePtr<ErrorDescriptor> m_ptrErrDesc;
+	std::auto_ptr<ErrorDescriptor> m_ptrErrDesc;
 };
 
 #endif
