@@ -28,8 +28,7 @@
 HttpResponseParser::HttpResponseParser()
 :	m_stateResponseStart(*this),
 	m_stateStatusLine(*this),
-	m_stateResponseHeaders(*this),
-	m_stateUnsizedFlatBody(*this)
+	m_stateResponseHeaders(*this)
 {
 }
 
