@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,12 +38,8 @@
 #include "SBOutStream.h"
 #include "StringUtils.h"
 #include "InsensitiveEqual.h"
-#include "ErrorDescriptor.h"
-#include "ErrorResponse.h"
-#include "ErrorCodes.h"
 #include <memory>
 #include <string>
-#include <list>
 
 using namespace std;
 
