@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,11 +61,11 @@ IframeHeuristicScore::processUrl(URI const& abs, URI const& rel, URI const& base
 	} else if (rship == URLS_SAME_HOST) {
 		m_score -= 40;
 	}
-	UrlStatus const status = getUrlStatus(rel);
-	if (status == URL_INNOCENT) {
-		m_score -= 20;
-	} else if (status == URL_SUSPICIOUS) {
+	UrlFlags const flags = getUrlStatus(abs, EXPECT_HTML);
+	if ((flags & LOOKS_LIKE_SCRIPT) && !(flags & UNEXPECTED_EXTENSION)) {
 		m_score += 20;
+	} else if (flags & HTML_EXTENSION) {
+		m_score -= 20;
 	}
 }
 
