@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,12 +32,14 @@
 #include "HttpResponseMetadata.h"
 #include "HttpHeadersCollection.h"
 #include "HeuristicScore.h"
-#include "CraftedResponse.h"
+#include "ImmediateResponse.h"
 #include "ReplacementImage.h"
 #include "DownloadProgress.h"
 #include "ErrorDescriptor.h"
+#include "ErrorFactory.h"
 #include "ErrorCodes.h"
 #include "IntrusivePtr.h"
+#include "RequestStatus.h"
 #include "RequestTag.h"
 #include "BString.h"
 #include <stddef.h>
@@ -59,17 +61,19 @@ ImageResponseFilter::~ImageResponseFilter()
 }
 
 void
-ImageResponseFilter::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
+ImageResponseFilter::processMetadata(
+	RequestStatus&, std::auto_ptr<HttpResponseMetadata> metadata)
 {
 	m_ptrMetadata = metadata;
 }
 
 void
-ImageResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
+ImageResponseFilter::processBodyData(
+	RequestStatus& status, SplittableBuffer& data, bool eof)
 {
 	switch (m_state) {
 		case FORWARDING: {
-			outputBodyData(data, eof);
+			outputBodyData(status, data, eof);
 			break;
 		}
 		case SUBSTITUTING: {
@@ -82,16 +86,20 @@ ImageResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
 				case AbstractImageInspector::COMPLETE: {
 					if (isAd()) {
 						m_state = SUBSTITUTING;
- 						outputAdSubstitution();
-						considerRequestCancel();
+ 						outputAdSubstitution(status);
+						considerRequestCancel(status);
 						break;
 					}
 					// fall through
 				}
 				case AbstractImageInspector::FAILED: {
 					m_state = FORWARDING;
-					outputMetadata(m_ptrMetadata);
-					outputBodyData(m_ptrInspector->accumulatedData(), eof);
+					outputMetadata(status, m_ptrMetadata);
+					outputBodyData(
+						status,
+						m_ptrInspector->accumulatedData(),
+						eof
+					);
 					break;
 				}
 				default: break;
@@ -114,33 +122,29 @@ ImageResponseFilter::isAd()
 }
 
 void
-ImageResponseFilter::outputAdSubstitution()
+ImageResponseFilter::outputAdSubstitution(RequestStatus& status)
 {
-	auto_ptr<CraftedResponse> response = ReplacementImage::createHttpResponse(
-		false, m_ptrInspector->getWidth(), m_ptrInspector->getHeight(),
-		HttpStatusLine::SC_OK
+	auto_ptr<ImmediateResponse> response(
+		ReplacementImage::createHttpResponse(
+			m_ptrInspector->getWidth(),
+			m_ptrInspector->getHeight(),
+			HttpStatusLine::SC_OK
+		)
 	);
-	
-	getRequestTag()->flags().set(RequestTag::RESPONSE_CRAFTED);
-	response->metadata().setClientRequestId(m_ptrMetadata->getClientRequestId());
-	response->metadata().headers().setHeader(
-		BString("X-BFilter-Content"), BString("generated")
-	);
-	outputMetadata(response->retrieveMetadata());
-	outputBodyData(response->body(), true);
+	outputResponse(status, *response);
 }
 
 void
-ImageResponseFilter::considerRequestCancel()
+ImageResponseFilter::considerRequestCancel(RequestStatus& status)
 {
 	DownloadProgress const& dp = getFilterChain().getDownloadProgress();
 	size_t threshold = GlobalState::ReadAccessor()->config().getSaveTrafficThreshold();
 	if (dp.total() - dp.received() > threshold*1024) { // or if dp.total() is undefined
-		raiseError(IntrusivePtr<ErrorDescriptor>(
-			new ErrorDescriptor(
+		status.cancel(
+			ErrorFactory::errDummyError(
 				ErrorCodes::REQUEST_CANCEL_TO_SAVE_TRAFFIC,
 				"request cancelled to save traffic"
 			)
-		));
+		);
 	}
 }
