@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,12 +26,12 @@
 
 #include <memory>
 
-class CraftedResponse;
+class ImmediateResponse;
 
 class ReplacementHtml
 {
 public:
-	static std::auto_ptr<CraftedResponse> createHttpResponse(bool is_head_response);
+	static std::auto_ptr<ImmediateResponse> createHttpResponse();
 };
 
 #endif
