@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 #include <config.h>
 #endif
 
+#include "AbstractServer.h"
 #include "HttpResponseParser.h"
 #include "ChainAsyncConnector.h"
 #include "ChainConnectorListener.h"
 #include "SplittableBuffer.h"
-#include "CraftedResponseGenerator.h"
 #include "ServerTimeouts.h"
 #include "SymbolicInetAddr.h"
 #include "AutoClosingSAP.h"
@@ -62,6 +62,7 @@ class SocksError;
 class ACE_SOCK_Stream;
 
 class Server :
+	public AbstractServer,
 	private HttpResponseParser,
 	private ChainConnectorListener,
 	private EventHandler<NullRefCounter>,
@@ -78,29 +79,17 @@ public:
 		RequestTag const& request_tag,
 		IntrusivePtr<AbstractResponseHandler> const& handler);
 	
-	IntrusivePtr<AbstractRequestHandler> submitRequest(
+	virtual IntrusivePtr<AbstractRequestHandler> submitRequest(
 		ConstRequestPtr const& request_metadata,
 		RequestTag const& request_tag,
 		IntrusivePtr<AbstractResponseHandler> const& handler,
-		std::auto_ptr<FilterTryList> filter_try_list);
+		std::auto_ptr<ImmediateResponse> response);
 	
-	IntrusivePtr<AbstractRequestHandler> submitRequest(
-		ConstRequestPtr const& request_metadata,
-		RequestTag const& request_tag,
-		IntrusivePtr<AbstractResponseHandler> const& handler,
-		IntrusivePtr<ErrorDescriptor> const& error_response);
+	virtual bool isIdle() const;
 	
-	IntrusivePtr<AbstractRequestHandler> submitRequest(
-		ConstRequestPtr const& request_metadata,
-		RequestTag const& request_tag,
-		IntrusivePtr<AbstractResponseHandler> const& handler,
-		CraftedResponseGenerator const& response_generator);
+	virtual bool isOverloaded() const;
 	
 	void reset();
-	
-	int getNumPendingRequests() const { return m_requestQueue.size(); }
-	
-	int getMaxPendingRequests() const { return MAX_PIPELINE_SIZE; }
 private:
 	enum { MAX_PIPELINE_SIZE = 4 };
 	enum { READ_BUF_SIZE = 16*1024 };
@@ -168,7 +157,7 @@ private:
 	
 	void restartPendingRequests();
 	
-	void answerWithError(IntrusivePtr<ErrorDescriptor> const& error_response);
+	void answerWithError(std::auto_ptr<ErrorDescriptor> edesc);
 	
 	bool isRequestAtPipelineStart(Request const* req) const;
 	
@@ -190,9 +179,9 @@ private:
 	
 	bool processLeadingErrorResponse();
 	
-	void processArtificialResponses();
+	void processImmediateResponses();
 	
-	bool isArtificialResponseRequired() const;
+	bool isImmediateResponseRequired() const;
 	
 	virtual void eventGotProvisionalResponse(
 		std::auto_ptr<HttpResponseMetadata> metadata);
