@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,19 +30,13 @@ class BString;
 class SubstitutionRequestParser
 {
 public:
-	SubstitutionRequestParser(bool head_response) : m_isHeadResponse(head_response) {}
-	
 	virtual ~SubstitutionRequestParser() {}
 	
-	bool isHeadResponse() const { return m_isHeadResponse; }
-	
 	bool parse(URI const& url, BString const& prefix);
 	
 	virtual void handleResult(
 		unsigned int width, unsigned int height,
 		URI const& url, BString const& orig_path) = 0;
-private:
-	bool m_isHeadResponse;
 };
 
 #endif
