@@ -31,6 +31,7 @@
 
 class HttpResponseMetadata;
 class ResponseFilterChain;
+class RequestStatus;
 
 class TextContentValidator : public ResponseFilterBase
 {
@@ -40,9 +41,12 @@ public:
 	
 	virtual ~TextContentValidator();
 	
-	virtual void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
+	virtual void processMetadata(
+		RequestStatus& status,
+		std::auto_ptr<HttpResponseMetadata> metadata);
 	
-	virtual void processBodyData(SplittableBuffer& data, bool eof);
+	virtual void processBodyData(
+		RequestStatus& status, SplittableBuffer& data, bool eof);
 private:
 	bool isText() const;
 	
