@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,11 +50,11 @@ WebbugHeuristicScore::processImageUrl(URI const& abs, URI const& rel, URI const&
 	} else if (rship == URLS_SAME_HOST) {
 		m_score -= 20;
 	}
-	UrlStatus const status = getUrlStatus(rel);
-	if (status == URL_INNOCENT) {
-		m_score -= 60;
-	} else if (status == URL_SUSPICIOUS) {
+	UrlFlags const flags = getUrlStatus(abs, EXPECT_IMAGE);
+	if (flags & LOOKS_LIKE_SCRIPT) {
 		m_score += 150;
+	} else {
+		m_score -= 60;
 	}
 }
 
