@@ -290,17 +290,22 @@ void
 WorkerThreadPool::processConnectionUnlocked(
 	ServiceContext& service_context, SocketPtr const& client_sock)
 {
-	Client client(service_context, client_sock);
-	Reactor& reactor = service_context.reactor();
-	Reactor::Status const reactor_status = reactor.runEventLoop();
-	if (reactor_status == Reactor::STOPPED) {
-		reactor.restart();
+	try {
+		Reactor& reactor = service_context.reactor();
+		Client client(client_sock, service_context.server(), reactor);
+		
+		Reactor::Status const reactor_status = reactor.runEventLoop();
+		if (reactor_status == Reactor::STOPPED) {
+			reactor.restart();
+		}
+		
+		// Should be called after the event loop, not before it.
+		// This way we release some resources before going to sleep
+		// waiting for a new task, not after it.
+		service_context.reset();
+	} catch (...) {
+		// Just terminate the session.
 	}
-	
-	// Should be called after the event loop, not before it.
-	// This way we release some resources before going to sleep
-	// waiting for a new task, not after it.
-	service_context.reset();
 }
 
 ACE_THR_FUNC_RETURN
