@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include "SymbolicInetAddr.h"
 #include "ProxyDescriptor.h"
 #include "PortSet.h"
+#include "types.h"
 #include <string>
 #include <list>
 #include <memory>
@@ -41,7 +42,7 @@ namespace Forwarding
 /**
  * \brief Represents the [forwarding] section of the "config" file.
  *
- * Starting from version 1.1, forwarding information is stored in the
+ * Starting from version 1.0.8, forwarding information is stored in the
  * "forwarding.xml" file.  Forwarding information from "config" is still
  * supported, and used when "forwarding.xml" is missing.
  */
@@ -158,6 +159,10 @@ public:
 	bool isTunnelPortAllowed(unsigned port) const;
 	
 	Forwarding::Config extractForwardingInfo() const;
+	
+	uint64_t getCacheSize() const { return m_cacheSize; }
+	
+	void setCacheSize(uint64_t cache_size) { m_cacheSize = cache_size; }
 private:
 	template<typename T> static void auto_ptr_swap(
 		std::auto_ptr<T>& o1, std::auto_ptr<T>& o2);
@@ -175,6 +180,7 @@ private:
 	ReportClientIP m_reportClientIP;
 	std::string m_fixedClientIP;
 	PortSet m_allowedTunnelPorts;
+	uint64_t m_cacheSize;
 };
 
 
