@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,6 +111,8 @@ private:
 	
 	bool handleAllowedTunnelPorts(std::string const& value, int line);
 	
+	bool handleCacheSize(std::string const& value, int line);
+	
 	bool handleUseProxy(std::string const& value, int line);
 	
 	bool handleProxyType(std::string const& value, int line);
@@ -228,6 +230,8 @@ private:
 	
 	void handleAllowedTunnelPorts(Element& el);
 	
+	void handleCacheSize(Element& el);
+	
 	static void commentOut(Element& el);
 	
 	std::list<Element>& m_rElements;
@@ -430,7 +434,8 @@ ConfigFileStructure::Reader::processKeyValue(
 			{ "max_script_eval_size", &Reader::handleMaxScriptEvalSize },
 			{ "save_traffic_threshold", &Reader::handleSaveTrafficThreshold },
 			{ "report_client_ip", &Reader::handleReportClientIP },
-			{ "allowed_tunnel_ports", &Reader::handleAllowedTunnelPorts }
+			{ "allowed_tunnel_ports", &Reader::handleAllowedTunnelPorts },
+			{ "cache_size", &Reader::handleCacheSize }
 		};
 		return handleParam(
 			handlers, handlers + ARRAY_SIZE(handlers),
@@ -720,6 +725,23 @@ ConfigFileStructure::Reader::handleAllowedTunnelPorts(std::string const& value,
 	return true;
 }
 
+bool
+ConfigFileStructure::Reader::handleCacheSize(std::string const& value, int line)
+{
+	uint64_t val;
+	try {
+		val = boost::lexical_cast<uint64_t>(value);
+	} catch (boost::bad_lexical_cast& e) {
+		ConfError err(
+			ConfError::T_ERROR,
+			"Illegal value for \"cache_size\"", line
+		);
+		return m_rErrorHandler.handleError(err);
+	}
+	m_rTarget.setCacheSize(val << 20); // size is in megabytes
+	return true;
+}
+
 bool
 ConfigFileStructure::Reader::handleUseProxy(std::string const& value, int line)
 {
@@ -953,7 +975,8 @@ ConfigFileStructure::Updater::handleGlobalSection(
 		{ false, "max_script_eval_size", &Updater::handleMaxScriptEvalSize },
 		{ false, "save_traffic_threshold", &Updater::handleSaveTrafficThreshold },
 		{ false, "report_client_ip", &Updater::handleReportClientIP },
-		{ false, "allowed_tunnel_ports", &Updater::handleAllowedTunnelPorts }
+		{ false, "allowed_tunnel_ports", &Updater::handleAllowedTunnelPorts },
+		{ false, "cache_size", &Updater::handleCacheSize }
 	};
 	ParamHandlerNode handlers[ARRAY_SIZE(handlers_proto)];
 	memcpy(handlers, handlers_proto, sizeof(handlers));
@@ -1132,6 +1155,14 @@ ConfigFileStructure::Updater::handleAllowedTunnelPorts(Element& el)
 	el.setValue(strm.str());
 }
 
+void
+ConfigFileStructure::Updater::handleCacheSize(Element& el)
+{
+	uint64_t size = m_rSource.getCacheSize();
+	size = (size + (1 << 20) - 1) >> 20; // convert to megabytes rounding upward
+	el.setValue(StringUtils::fromNumber(size));
+}
+
 void
 ConfigFileStructure::Updater::commentOut(Element& el)
 {
