@@ -68,13 +68,19 @@ UrlPatterns::~UrlPatterns()
 UrlPatterns&
 UrlPatterns::operator=(UrlPatterns const& other)
 {
-	m_allowPatterns = other.m_allowPatterns;
-	m_noFilterPatterns = other.m_noFilterPatterns;
-	m_substPatterns = other.m_substPatterns;
-	m_hintPatterns = other.m_hintPatterns;
+	UrlPatterns(other).swap(*this);
 	return *this;
 }
 
+void
+UrlPatterns::swap(UrlPatterns& other)
+{
+	m_allowPatterns.swap(other.m_allowPatterns);
+	m_noFilterPatterns.swap(other.m_noFilterPatterns);
+	m_substPatterns.swap(other.m_substPatterns);
+	m_hintPatterns.swap(other.m_hintPatterns);
+}
+
 void
 UrlPatterns::clear()
 {
