@@ -25,7 +25,7 @@
 #endif
 
 #include "IntrusivePtr.h"
-#include <deque>
+#include <vector>
 #include <utility>
 
 class BString;
@@ -48,6 +48,8 @@ public:
 	
 	UrlPatterns& operator=(UrlPatterns const& other);
 	
+	void swap(UrlPatterns& other);
+	
 	void clear();
 	
 	void addAllowPattern(PatternPtr const& pattern);
@@ -66,10 +68,10 @@ public:
 	
 	int getHintFor(BString const& subj) const;
 private:
-	typedef std::deque<PatternPtr> AllowPatterns;
-	typedef std::deque<PatternPtr> NoFilterPatterns;
-	typedef std::deque<std::pair<PatternPtr, Substitution> > SubstPatterns;
-	typedef std::deque<std::pair<PatternPtr, int> > HintPatterns;
+	typedef std::vector<PatternPtr> AllowPatterns;
+	typedef std::vector<PatternPtr> NoFilterPatterns;
+	typedef std::vector<std::pair<PatternPtr, Substitution> > SubstPatterns;
+	typedef std::vector<std::pair<PatternPtr, int> > HintPatterns;
 	
 	template<typename Iter>
 	static bool findMatch(Iter begin, Iter end, BString const& subj);
@@ -80,4 +82,10 @@ private:
 	HintPatterns m_hintPatterns;
 };
 
+
+inline void swap(UrlPatterns& o1, UrlPatterns& o2)
+{
+	o1.swap(o2);
+}
+
 #endif
