@@ -50,6 +50,7 @@
 #include "ArraySize.h"
 #include "Alarm.h"
 #include "types.h"
+#include "cache/ObjectStorage.h"
 #ifdef ENABLE_BINRELOC
 #include "binreloc/prefix.h"
 #endif
@@ -63,6 +64,8 @@
 #include <ace/Dirent.h>
 #include <ace/SOCK_Acceptor.h>
 #include <ace/Signal.h>
+#include <ace/OS_NS_Thread.h> // for ACE_OS::sigwait()
+#include <ace/OS_NS_signal.h> // for ACE_OS::sigprocmask()
 #include <ace/FILE_IO.h>
 #include <ace/FILE_Addr.h>
 #include <ace/FILE_Connector.h>
@@ -78,15 +81,23 @@
 #include <exception>
 #include <sys/types.h>
 #include <sys/file.h>
+#include <sys/stat.h>
+#include <errno.h>
+#include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include <netdb.h>
 #include <pwd.h>
 #include <grp.h>
+#include <assert.h>
 
 namespace po = boost::program_options;
 using namespace std;
 
-class Daemon::ScopeSetEUID
+namespace
+{
+
+class ScopeSetEUID
 {
 public:
 	ScopeSetEUID(uid_t euid);
@@ -97,7 +108,7 @@ private:
 };
 
 
-class Daemon::ScopeSetEGID
+class ScopeSetEGID
 {
 public:
 	ScopeSetEGID(gid_t egid);
@@ -108,6 +119,31 @@ private:
 };
 
 
+ScopeSetEUID::ScopeSetEUID(uid_t euid)
+{
+	m_prevEUID = geteuid();
+	seteuid(euid);
+}
+
+ScopeSetEUID::~ScopeSetEUID()
+{
+	seteuid(m_prevEUID);
+}
+
+ScopeSetEGID::ScopeSetEGID(gid_t egid)
+{
+	m_prevEGID = getegid();
+	setegid(egid);
+}
+
+ScopeSetEGID::~ScopeSetEGID()
+{
+	setegid(m_prevEGID);
+}
+
+} // anonymous namespace
+
+
 class Daemon::ConfigErrorHandler : public ConfErrorHandler
 {
 public:
@@ -243,34 +279,6 @@ private:
 #endif // ENABLE_RECONFIGURE
 
 
-/*========================= Daemon::ScopeSetEUID =========================*/
-
-Daemon::ScopeSetEUID::ScopeSetEUID(uid_t euid)
-{
-	m_prevEUID = geteuid();
-	seteuid(euid);
-}
-
-Daemon::ScopeSetEUID::~ScopeSetEUID()
-{
-	seteuid(m_prevEUID);
-}
-
-
-/*========================= Daemon::ScopeSetEGID =========================*/
-
-Daemon::ScopeSetEGID::ScopeSetEGID(gid_t egid)
-{
-	m_prevEGID = getegid();
-	setegid(egid);
-}
-
-Daemon::ScopeSetEGID::~ScopeSetEGID()
-{
-	setegid(m_prevEGID);
-}
-
-
 /* ==================== Daemon::ConfigErrorHandler =======================*/
 
 bool
@@ -776,16 +784,19 @@ Daemon::Reconfigurer::updateNetworkProfiles(int listen_port)
 
 /*=========================== Daemon ==================================*/
 
-volatile bool Daemon::m_sSigtermReceived = false;
-volatile bool Daemon::m_sSigintReceived = false;
-
 bool
-Daemon::init(std::string const& confdir)
+Daemon::init(std::string const& confdir, std::string const& cache_dir)
 {
 	if (!loadConfiguration(confdir)) {
 		return false;
 	}
 	
+	if (!cache_dir.empty()) {
+		if (!initCache(cache_dir)) {
+			return false;
+		}
+	}
+	
 	if (!bind()) {
 		return false;
 	}
@@ -802,11 +813,13 @@ Daemon::run(bool nodaemon, ACE_FILE_IO& pid_file)
 		}
 	}
 	
-	{
-		ACE_Sig_Action sigpipe_action(SIG_IGN, SIGPIPE);
-		ACE_Sig_Action sigterm_action(&Daemon::sigtermHandler, SIGTERM);
-		ACE_Sig_Action sigint_action(&Daemon::sigintHandler, SIGINT);
-	}
+	ACE_Sig_Action(SIG_IGN, SIGPIPE);
+	
+	ACE_Sig_Set termsigs;
+	termsigs.sig_add(SIGTERM);
+	termsigs.sig_add(SIGINT);
+	ACE_Sig_Set oldsigs;
+	ACE_OS::sigprocmask(SIG_BLOCK, termsigs, oldsigs);
 	
 	if (pid_file.get_handle() != ACE_INVALID_HANDLE) {
 		ostringstream strm;
@@ -822,9 +835,7 @@ Daemon::run(bool nodaemon, ACE_FILE_IO& pid_file)
 	
 	m_workerPool.activate();
 	
-	while (!m_sSigtermReceived && !m_sSigintReceived) {
-		sleep(10000);
-	}
+	ACE_OS::sigwait(termsigs);
 	
 	if (pid_file.get_handle() != ACE_INVALID_HANDLE) {
 		// It would be better to delete the pid file,
@@ -992,6 +1003,26 @@ Daemon::loadConfiguration(std::string const& confdir)
 	return true;
 }
 
+bool
+Daemon::initCache(std::string const& cache_dir)
+{
+	if (GlobalState::ReadAccessor()->config().getCacheSize() == 0) {
+		return true;
+	}
+	
+	if (!HttpCache::ObjectStorage::instance()->setCacheDir(cache_dir)) {
+		if (access(cache_dir.c_str(), R_OK|W_OK|X_OK|F_OK) == 0) {
+			fprintf(stderr, "Can't use %s as a cache directory for unknown reason.\n", cache_dir.c_str());
+		} else if (errno == ENOENT || errno == ENOTDIR) {
+			fprintf(stderr, "%s doesn't exist.\n", cache_dir.c_str());
+		} else {
+			fprintf(stderr, "%s doesn't have correct permissions.\n", cache_dir.c_str());
+		}
+		return false;
+	}
+	return true;
+}
+
 bool
 Daemon::bind()
 {
@@ -1034,18 +1065,6 @@ Daemon::bind()
 	return true;
 }
 
-void
-Daemon::sigtermHandler(int)
-{
-	m_sSigtermReceived = true;
-}
-
-void
-Daemon::sigintHandler(int)
-{
-	m_sSigintReceived = true;
-}
-
 
 /* =============================== main ================================*/
 
@@ -1063,8 +1082,10 @@ int main(int argc, char **argv)
 	bool kill_running = false;
 	bool reconfigure = false;
 	string confdir;
+	string cache_dir;
 	string chroot_dir;
-	string effective_confdir; // relative to chroot_dir
+	string effective_confdir;  // 
+	string effective_cachedir; // relative to chroot_dir
 #if defined(SYSCONFDIR)
 	// binreloc may redefine SYSCONFDIR
 	confdir = string(SYSCONFDIR) + "/bfilter";
@@ -1080,6 +1101,9 @@ int main(int argc, char **argv)
 			("help,h", "Print help message")
 			("version,v", "Print version")
 			("confdir,c", po::value<string>(&confdir), "Set custom config directory")
+			("cachedir,C", po::value<string>(&cache_dir), "Set cache directory. "
+				"May be relative to config directory."
+			)
 			("chroot,r", po::value<string>(&chroot_dir),
 				"Set chroot directory. It must contain the config "
 				"directory and may be specified relative to it."
@@ -1138,16 +1162,18 @@ int main(int argc, char **argv)
 		}
 	}
 	
-	if (confdir[0] != '/') {
+	if (confdir.c_str()[0] != '/') {
 		std::cerr << "Config directory must be absolute" << std::endl;
 		return EXIT_FAILURE;
 	}
 	
 	confdir = Daemon::normalizePath(confdir);
+	cache_dir = Daemon::normalizePath(cache_dir);
 	effective_confdir = confdir;
+	effective_cachedir = cache_dir;
 	
 	if (!chroot_dir.empty()) {
-		if (chroot_dir[0] == '/') {
+		if (chroot_dir.c_str()[0] == '/') {
 			chroot_dir = Daemon::normalizePath(chroot_dir);
 		} else {
 			chroot_dir = Daemon::normalizePath(confdir+'/'+chroot_dir);
@@ -1161,6 +1187,21 @@ int main(int argc, char **argv)
 			std::cerr << "Config directory must be within the chroot directory" << std::endl;
 			return EXIT_FAILURE;
 		}
+		
+		if (!cache_dir.empty()) {
+			if (cache_dir.c_str()[0] == '/') {
+				cache_dir = Daemon::normalizePath(cache_dir);
+			} else {
+				cache_dir = Daemon::normalizePath(confdir+'/'+cache_dir);
+			}
+			
+			if (StringUtils::startsWith(cache_dir, chroot_dir)) {
+				effective_cachedir = cache_dir.substr(cache_dir.size());
+			} else {
+				std::cerr << "Cache directory must be within the chroot directory" << std::endl;
+				return EXIT_FAILURE;
+			}
+		}
 	}
 	
 	Daemon::initResolver();
@@ -1185,17 +1226,6 @@ int main(int argc, char **argv)
 		}
 	}
 	
-	if (!chroot_dir.empty()) {
-		if (chdir(chroot_dir.c_str())) {
-			std::cerr << "Could not chdir to " << chroot_dir << std::endl;
-			return EXIT_FAILURE;
-		}
-		if (chroot(chroot_dir.c_str())) {
-			std::cerr << "Could not chroot to " << chroot_dir << std::endl;
-			return EXIT_FAILURE;
-		}
-	}
-	
 #if defined(ENABLE_RECONFIGURE)
 	// This must come before dropping priviledges or chroot()ing.
 	if (reconfigure) {
@@ -1210,6 +1240,17 @@ int main(int argc, char **argv)
 	}
 #endif
 	
+	if (!chroot_dir.empty()) {
+		if (chdir(chroot_dir.c_str())) {
+			std::cerr << "Could not chdir to " << chroot_dir << std::endl;
+			return EXIT_FAILURE;
+		}
+		if (chroot(chroot_dir.c_str())) {
+			std::cerr << "Could not chroot to " << chroot_dir << std::endl;
+			return EXIT_FAILURE;
+		}
+	}
+	
 	if (group_r) {
 		if (setgid(group_r->gr_gid)) {
 			std::cerr << "Could not drop priviliges: setgid() failed" << std::endl;
@@ -1225,7 +1266,7 @@ int main(int argc, char **argv)
 	
 	
 	Daemon daemon;
-	if (!daemon.init(effective_confdir)) {
+	if (!daemon.init(effective_confdir, effective_cachedir)) {
 		return EXIT_FAILURE;
 	}
 	if (!daemon.run(nodaemon, pid_file)) {
