@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 
 #include <gtkmm/dialog.h>
 
+namespace GtkGUI
+{
+
 class AboutDialog : public Gtk::Dialog
 {
 private:
@@ -40,4 +43,6 @@ private:
 	static AboutDialog* m_spInstance;
 };
 
+} // namespace GtkGUI
+
 #endif
