@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,16 +27,14 @@
 #include "AutoScrollingWindow.h"
 #include "Application.h"
 #include "OperationLog.h"
-#include "Conf.h"
 #include "ConfigFile.h"
-#include "UrlPatterns.h"
-#include "UrlPatternsFile.h"
+#include "UrlsFile.h"
 #include "SharedPtr.h"
 #include "GlobalState.h"
+#include "FileVersion.h"
+#include "FileOps.h"
+#include "EncOps.h"
 #include "CompiledImages.h"
-#include "EffectiveFileTimestamps.h"
-#include <ace/config-lite.h>
-#include <ace/OS_NS_sys_stat.h>
 #include <glibmm/convert.h>
 #include <gtkmm/textview.h>
 #include <gtkmm/box.h>
@@ -57,10 +55,12 @@
 #include <sstream>
 #include <cassert>
 #include <stddef.h>
-#include <time.h>
 
 using namespace std;
 
+namespace GtkGUI
+{
+
 class AdvancedConfigWindow::Button : public Gtk::Button
 {
 public:
@@ -103,25 +103,37 @@ public:
 	
 	bool isModified() const { return m_isModified; }
 	
-	time_t getFileLoadTimestamp() const { return m_fileLoadTimestamp; }
+	FileVersion const& getLoadedFileVersion() const {
+		return m_loadedFileVersion;
+	}
 	
-	void setFileLoadTimestamp(time_t val) { m_fileLoadTimestamp = val; }
+	void setLoadedFileVersion(FileVersion const& version) {
+		m_loadedFileVersion = version;
+	}
 	
-	time_t getFileCurrentTimestamp() const { return m_fileCurrentTimestamp; }
+	FileVersion const& getLastKnownFileVersion() const {
+		return m_lastKnownFileVersion;
+	}
 
-	void setFileCurrentTimestamp(time_t val) { m_fileCurrentTimestamp = val; }
+	void setLastKnownFileVersion(FileVersion const& version) {
+		m_lastKnownFileVersion = version;
+	}
 	
 	void unselectTextOnce();
 	
 	void updateState();
 	
-	bool updateFileCurrentTimestamp(); // returns true if changed
+	bool updateLastKnownFileVersion(); // returns true if changed
 	
 	virtual Glib::ustring const& getTabName() const = 0;
 	
-	virtual time_t getFileEffectiveTimestamp() const { return 0; }
+	virtual FileVersion getEffectiveFileVersion() const {
+		return FileVersion::undefined();
+	}
 	
-	virtual time_t readFileCurrentTimestamp() const { return 0; }
+	virtual FileVersion readCurrentFileVersion() const {
+		return FileVersion::undefined();
+	}
 	
 	virtual void loadFile() = 0;
 	
@@ -135,8 +147,8 @@ private:
 	int const m_notebookPage;
 	Glib::RefPtr<Gtk::TextBuffer> m_ptrTextBuffer;
 	Gtk::TextView* m_pTextView;
-	time_t m_fileLoadTimestamp;
-	time_t m_fileCurrentTimestamp;
+	FileVersion m_loadedFileVersion;
+	FileVersion m_lastKnownFileVersion;
 	bool m_isModified;
 };
 
@@ -152,9 +164,9 @@ public:
 	
 	virtual Glib::ustring const& getTabName() const;
 	
-	virtual time_t getFileEffectiveTimestamp() const;
+	virtual FileVersion getEffectiveFileVersion() const;
 	
-	virtual time_t readFileCurrentTimestamp() const;
+	virtual FileVersion readCurrentFileVersion() const;
 	
 	virtual void loadFile();
 	
@@ -162,8 +174,6 @@ public:
 	
 	virtual void onSave();
 private:
-	bool restoreOldConfig(Config const& config);
-	
 	Glib::ustring m_unmodifiedTabName;
 	Glib::ustring m_modifiedTabName;
 };
@@ -214,9 +224,9 @@ public:
 	
 	virtual Glib::ustring const& getTabName() const;
 	
-	virtual time_t getFileEffectiveTimestamp() const;
+	virtual FileVersion getEffectiveFileVersion() const;
 	
-	virtual time_t readFileCurrentTimestamp() const;
+	virtual FileVersion readCurrentFileVersion() const;
 	
 	virtual void loadFile();
 	
@@ -392,6 +402,12 @@ AdvancedConfigWindow::showWindow()
 	}
 }
 
+void
+AdvancedConfigWindow::on_hide()
+{
+	delete this;
+}
+
 bool
 AdvancedConfigWindow::on_delete_event(GdkEventAny*)
 {
@@ -429,7 +445,7 @@ AdvancedConfigWindow::onFocusChange(GdkEventFocus*)
 	if (active) {
 		for (int i = m_pNotebook->get_n_pages() - 1; i >= 0; --i) {
 			Page* page = getPage(i);
-			if (page->updateFileCurrentTimestamp()) {
+			if (page->updateLastKnownFileVersion()) {
 				page->updateState();
 			}
 		}
@@ -560,8 +576,6 @@ AdvancedConfigWindow::Page::Page(
 	m_notebookPage(notebook_page),
 	m_ptrTextBuffer(Gtk::TextBuffer::create()),
 	m_pTextView(0),
-	m_fileLoadTimestamp(0),
-	m_fileCurrentTimestamp(0),
 	m_isModified(false)
 {
 	set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -607,7 +621,7 @@ AdvancedConfigWindow::Page::isPageSelected() const
 std::string
 AdvancedConfigWindow::Page::getText() const
 {
-	return Application::localeFromUtf8(m_ptrTextBuffer->get_text());
+	return EncOps::localeFromUtf8(m_ptrTextBuffer->get_text());
 }
 
 void
@@ -623,9 +637,9 @@ AdvancedConfigWindow::Page::updateState()
 {
 	bool const text_modified = isTextModified();
 	bool const file_is_newer =
-		(m_fileCurrentTimestamp != m_fileLoadTimestamp);
+		(m_lastKnownFileVersion != m_loadedFileVersion);
 	bool const file_not_effective =
-		(getFileEffectiveTimestamp() != m_fileLoadTimestamp);
+		(getEffectiveFileVersion() != m_loadedFileVersion);
 	
 	bool const was_modified = m_isModified;
 	m_isModified = text_modified || file_not_effective;
@@ -652,12 +666,12 @@ AdvancedConfigWindow::Page::updateState()
 }
 
 bool
-AdvancedConfigWindow::Page::updateFileCurrentTimestamp()
+AdvancedConfigWindow::Page::updateLastKnownFileVersion()
 {
-	time_t const new_tstamp = readFileCurrentTimestamp();
-	time_t const old_tstamp = getFileCurrentTimestamp();
-	setFileCurrentTimestamp(new_tstamp);
-	return (old_tstamp != new_tstamp);
+	FileVersion const current(readCurrentFileVersion());
+	FileVersion const last_known(getLastKnownFileVersion());
+	setLastKnownFileVersion(current);
+	return (current != last_known);
 }
 
 
@@ -682,21 +696,17 @@ AdvancedConfigWindow::ConfigPage::getTabName() const
 	return isModified() ? m_modifiedTabName : m_unmodifiedTabName;
 }
 
-time_t
-AdvancedConfigWindow::ConfigPage::getFileEffectiveTimestamp() const
+FileVersion
+AdvancedConfigWindow::ConfigPage::getEffectiveFileVersion() const
 {
-	return EffectiveFileTimestamps::config;
+	return GlobalState::ReadAccessor()->getConfigFileVersion();
 }
 
-time_t
-AdvancedConfigWindow::ConfigPage::readFileCurrentTimestamp() const
+FileVersion
+AdvancedConfigWindow::ConfigPage::readCurrentFileVersion() const
 {
 	Application& app = *Application::instance();
-	ACE_stat st;
-	if (ACE_OS::stat(app.getConfigFileName().c_str(), &st) != -1) {
-		return st.st_mtime;
-	}
-	return 0;
+	return app.configFile().readFileVersion();
 }
 
 void
@@ -704,11 +714,11 @@ AdvancedConfigWindow::ConfigPage::loadFile()
 {
 	Application& app = *Application::instance();
 	string content;
-	time_t mtime = 0;
-	app.readFile(app.getConfigFileName(), content, &mtime);
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	setText(app.localeToUtf8(content));
+	FileVersion version;
+	FileOps::readFile(app.getConfigFileName(), content, &version);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
+	setText(EncOps::localeToUtf8(content));
 }
 
 void
@@ -721,62 +731,20 @@ void
 AdvancedConfigWindow::ConfigPage::onSave()
 {
 	Application& app = *Application::instance();
-	Log* log = OperationLog::instance();
-	log->appendRecord("Applying new config ... ");
-	size_t num_records = log->getNumRecords();
-	
-	string const text = getText();
-	Config new_config;
-	ConfigFile new_config_file;
-	
-	if (!app.processConfig(text, new_config, new_config_file)) {
+
+	if (!app.configFile().applyAndSave(getText())) {
 		return;
 	}
 	
-	Config old_config(GlobalState::ReadAccessor()->config());
-	
-	if (!app.applyConfig(new_config)) {
-		restoreOldConfig(old_config);
-		return;
-	}
-	
-	time_t mtime = 0;
-	if (!app.writeFile(app.getConfigFileName(), text, &mtime)) {
-		restoreOldConfig(old_config);
-		return;
-	}
-	
-	app.configFile().swap(new_config_file);
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord("done", log->getSuccessStyle());
-	}
-	
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	EffectiveFileTimestamps::config = mtime;
+	FileVersion const version(
+		GlobalState::ReadAccessor()->getConfigFileVersion()
+	);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setTextUnmodified();
 	updateState();
 }
 
-bool
-AdvancedConfigWindow::ConfigPage::restoreOldConfig(Config const& config)
-{
-	Application& app = *Application::instance();
-	Log* log = OperationLog::instance();
-	log->appendRecord("Restoring the old config ... ");
-	size_t num_records = log->getNumRecords();
-	
-	if (!app.applyConfig(config)) {
-		return false;
-	}
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord("done", log->getSuccessStyle());
-	}
-	return true;
-}
-
 
 /*============= AdvancedConfigWindow::ConfigDefaultPage =================*/
 
@@ -803,8 +771,8 @@ AdvancedConfigWindow::ConfigDefaultPage::loadFile()
 {
 	Application& app = *Application::instance();
 	string content;
-	app.readFile(app.getConfigDefaultFileName(), content);
-	setText(app.localeToUtf8(content));
+	FileOps::readFile(app.getConfigDefaultFileName(), content);
+	setText(EncOps::localeToUtf8(content));
 }
 
 
@@ -833,8 +801,8 @@ AdvancedConfigWindow::UrlsPage::loadFile()
 {
 	Application& app = *Application::instance();
 	string content;
-	app.readFile(app.getStandardUrlPatternsFileName(), content);
-	setText(app.localeToUtf8(content));
+	FileOps::readFile(app.getStandardUrlPatternsFileName(), content);
+	setText(EncOps::localeToUtf8(content));
 }
 
 
@@ -859,21 +827,17 @@ AdvancedConfigWindow::UrlsLocalPage::getTabName() const
 	return isModified() ? m_modifiedTabName : m_unmodifiedTabName;
 }
 
-time_t
-AdvancedConfigWindow::UrlsLocalPage::getFileEffectiveTimestamp() const
+FileVersion
+AdvancedConfigWindow::UrlsLocalPage::getEffectiveFileVersion() const
 {
-	return EffectiveFileTimestamps::urls_local;
+	return GlobalState::ReadAccessor()->getUrlsLocalFileVersion();
 }
 
-time_t
-AdvancedConfigWindow::UrlsLocalPage::readFileCurrentTimestamp() const
+FileVersion
+AdvancedConfigWindow::UrlsLocalPage::readCurrentFileVersion() const
 {
 	Application& app = *Application::instance();
-	ACE_stat st;
-	if (ACE_OS::stat(app.getLocalUrlPatternsFileName().c_str(), &st) != -1) {
-		return st.st_mtime;
-	}
-	return 0;
+	return app.urlsLocalFile().readFileVersion();
 }
 
 void
@@ -881,11 +845,11 @@ AdvancedConfigWindow::UrlsLocalPage::loadFile()
 {
 	Application& app = *Application::instance();
 	string content;
-	time_t mtime = 0;
-	app.readFile(app.getLocalUrlPatternsFileName(), content, &mtime);
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	setText(app.localeToUtf8(content));
+	FileVersion version;
+	FileOps::readFile(app.getLocalUrlPatternsFileName(), content, &version);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
+	setText(EncOps::localeToUtf8(content));
 }
 
 void
@@ -898,33 +862,18 @@ void
 AdvancedConfigWindow::UrlsLocalPage::onSave()
 {
 	Application& app = *Application::instance();
-	Log* log = OperationLog::instance();
-	log->appendRecord("Applying new local url patterns ... ");
-	size_t num_records = log->getNumRecords();
-	
-	string const text = getText();
-	UrlPatterns new_patterns;
-	UrlPatternsFile new_patterns_file;
-	
-	if (!app.processUrlPatterns(text, "urls.local",
-		                    new_patterns, new_patterns_file)) {
+
+	if (!app.urlsLocalFile().applyAndSave(getText())) {
 		return;
 	}
 	
-	time_t mtime = 0;
-	if (!app.writeFile(app.getLocalUrlPatternsFileName(), text, &mtime)) {
-		return;
-	}
-	
-	app.applyLocalUrlPatterns(new_patterns);
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord("done", log->getSuccessStyle());
-	}
-	
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	EffectiveFileTimestamps::urls_local = mtime;
+	FileVersion const version(
+		GlobalState::ReadAccessor()->getUrlsLocalFileVersion()
+	);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setTextUnmodified();
 	updateState();
 }
+
+} // namespace GtkGUI
