@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,6 +30,9 @@
 
 using namespace std;
 
+namespace GtkGUI
+{
+
 AnimatedTrayIcon::AnimatedTrayIcon()
 :	m_statusIcon("BFilter")
 {
@@ -161,3 +164,5 @@ AnimatedTrayIcon::Animation::swap(Animation& other)
 	std::swap(tooltip, other.tooltip);
 	std::swap(flags, other.flags);
 }
+
+} // namespace GtkGUI
