@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,6 +32,9 @@
 #include <gdk/gdkevents.h>
 #include <vector>
 
+namespace GtkGUI
+{
+
 class AnimatedTrayIcon
 {
 public:
@@ -122,4 +125,6 @@ AnimatedTrayIcon::setAnimation(
 	}
 }
 
+} // namespace GtkGUI
+
 #endif
