@@ -130,7 +130,7 @@ Application::Application(int argc, char* argv[])
 #ifdef DEBUG
 	m_ptrDebugWindow.reset(new DebugWindow);
 #endif
-	m_dispatcher.connect(
+	m_wakeupPipe.wakeupSignal().connect(
 		sigc::mem_fun(*this, &Application::processCommands)
 	);
 }
@@ -264,7 +264,7 @@ Application::handleNetworkActivity()
 void
 Application::notifyCommandsPending()
 {
-	m_dispatcher.emit();
+	m_wakeupPipe.wakeup();
 }
 
 // Note: this function is called from the main thread only.
@@ -299,7 +299,7 @@ Application::processCommands()
 		}
 		(*command)();
 	}
-	m_dispatcher.emit(); // there could be more commands in the queue
+	m_wakeupPipe.wakeup(); // there could be more commands in the queue
 }
 
 bool
