@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 
 #include <gtkmm/textview.h>
 
+namespace GtkGUI
+{
+
 class AutoIndentingTextView : public Gtk::TextView
 {
 public:
@@ -37,4 +40,6 @@ private:
 	virtual bool on_key_press_event(GdkEventKey* evt);
 };
 
+} // namespace GtkGUI
+
 #endif
