@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,14 +38,18 @@
 #include <string>
 #include <map>
 
-class DebugLayout;
-class DebugMessage;
-class ClientRequestDescriptor;
 class SplittableBuffer;
 namespace Gtk {
 	class TextBuffer;
 }
 
+namespace GtkGUI
+{
+
+class DebugLayout;
+class DebugMessage;
+class ClientRequestDescriptor;
+
 class DebugConnection :
 	public Gtk::EventBox,
 	public RefCountable<RefCounter<ACE_NULL_SYNCH> >
@@ -135,4 +139,6 @@ private:
 	sigc::signal<void> m_destroySignal;
 };
 
+} // namespace GtkGUI
+
 #endif
