@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@
 
 using namespace std;
 
+namespace GtkGUI
+{
+
 class DebugMessage::ContentWindow : public Gtk::Window
 {
 public:
@@ -336,3 +339,5 @@ DebugMessage::ContentWindow::on_hide()
 {
 	delete this;
 }
+
+} // namespace GtkGUI
