@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,9 @@
 #include "NetworkActivityReporter.h"
 #include "Application.h"
 
+namespace GtkGUI
+{
+
 NetworkActivityHandler::NetworkActivityHandler(InterthreadCommandQueue& command_queue)
 :	m_rCommandQueue(command_queue)
 {
@@ -48,3 +51,5 @@ NetworkActivityHandler::handleNetworkActivity()
 {
 	Application::instance()->handleNetworkActivity();
 }
+
+} // namespace GtkGUI
