@@ -24,7 +24,7 @@
 #endif
 
 #include "OperationLog.h"
-#include "Application.h"
+#include "EncOps.h"
 #include "StringUtils.h"
 #include <ace/config-lite.h>
 #include <ace/Synch.h>
@@ -35,6 +35,9 @@
 
 using namespace std;
 
+namespace GtkGUI
+{
+
 OperationLog::OperationLog()
 {
 	m_ptrMonospacedStyle = getTextBuffer()->create_tag();
@@ -59,7 +62,7 @@ OperationLog::appendJsError(
 	if (linebuf.empty()) {
 		ostringstream strm;
 		strm << '[' << lineno << "] " << msg;
-		Glib::ustring text(Application::localeToUtf8(strm.str()));
+		Glib::ustring text(EncOps::localeToUtf8(strm.str()));
 		appendRecord(text, getWarningStyle());
 		return;
 	}
@@ -79,8 +82,10 @@ OperationLog::appendJsError(
 	strm1 << '[' << lineno << "] " << msg;
 	ostringstream strm2;
 	strm2 << "\n" << line << "\n" << pointer;
-	Glib::ustring line1(Application::localeToUtf8(strm1.str()));
-	Glib::ustring line2(Application::localeToUtf8(strm2.str()));
+	Glib::ustring line1(EncOps::localeToUtf8(strm1.str()));
+	Glib::ustring line2(EncOps::localeToUtf8(strm2.str()));
 	appendRecord(line1, getWarningStyle());
 	appendToLastRecord(line2, m_ptrMonospacedStyle);
 }
+
+} // namespace GtkGUI
