@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,9 @@
 #include "Log.h"
 #include <string>
 
+namespace GtkGUI
+{
+
 class OperationLog : public Log
 {
 public:
@@ -43,4 +46,6 @@ private:
 	StylePtr m_ptrMonospacedStyle;
 };
 
+} // namespace GtkGUI
+
 #endif
