@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@
 
 struct CompiledImage;
 
+namespace GtkGUI
+{
+
 class TrayIcon : public AnimatedTrayIcon, public sigc::trackable
 {
 public:
@@ -72,4 +75,6 @@ private:
 	Glib::RefPtr<Gdk::Pixbuf> m_ptrInoperativeIcon;
 };
 
+} // namespace Gtk
+
 #endif
