@@ -24,39 +24,28 @@
 #include <config.h>
 #endif
 
-#include <gtkmm/menu.h>
+#include "NonCopyable.h"
+#include <glib/gtypes.h>
+#include <memory>
 
-class TrayMenu : public Gtk::Menu
+namespace GtkGUI
 {
+
+class TrayMenu
+{
+	DECLARE_NON_COPYABLE(TrayMenu)
 public:
 	TrayMenu();
+	
+	~TrayMenu();
+	
+	void popup(guint button, guint32 activate_time);
 private:
-	void updateActiveItemText();
+	class Impl;
 	
-	void onActive();
-	
-	void onActiveSelected();
-	
-	void onActiveDeselected();
-	
-	void onBasicConfig();
-	
-	void onAdvancedConfig();
-	
-	void onFilterConfig();
-	
-	void onOperationLog();
-	
-	void onRequestLog();
-#ifdef DEBUG
-	void onDebug();
-#endif
-	void onAbout();
-	
-	void onQuit();
-	
-	Gtk::CheckMenuItem* m_pActiveItem;
-	bool m_isActiveItemSelected;
+	std::auto_ptr<Impl> m_ptrImpl;
 };
 
+} // namespace GtkGUI
+
 #endif
