@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,18 +27,19 @@
 #include "Application.h"
 #include "OperationLog.h"
 #include "LogWidget.h"
-#include "Conf.h"
 #include "ConfigFile.h"
-#include "UrlPatterns.h"
-#include "UrlPatternsFile.h"
+#include "UrlsFile.h"
 #include "SharedPtr.h"
 #include "GlobalState.h"
-#include "EffectiveFileTimestamps.h"
+#include "FileVersion.h"
+#include "FileOps.h"
 #include <ace/config-lite.h>
-#include <ace/OS_NS_sys_stat.h>
 #include <wx/string.h>
+#include <wx/sizer.h>
 #include <wx/button.h>
 #include <wx/notebook.h>
+#include <wx/statbox.h>
+#include <wx/msgdlg.h>
 #include <wx/panel.h>
 #include <wx/textctrl.h>
 #include <wx/statusbr.h>
@@ -53,6 +54,9 @@
 
 using namespace std;
 
+namespace wxGUI
+{
+
 class AdvancedConfigWindow::Button : public wxButton
 {
 public:
@@ -117,25 +121,37 @@ public:
 	
 	bool isModified() const { return m_isModified; }
 	
-	time_t getFileLoadTimestamp() const { return m_fileLoadTimestamp; }
+	FileVersion const& getLoadedFileVersion() const {
+		return m_loadedFileVersion;
+	}
 	
-	void setFileLoadTimestamp(time_t val) { m_fileLoadTimestamp = val; }
+	void setLoadedFileVersion(FileVersion const& version) {
+		m_loadedFileVersion = version;
+	}
 	
-	time_t getFileCurrentTimestamp() const { return m_fileCurrentTimestamp; }
+	FileVersion const& getLastKnownFileVersion() const {
+		return m_lastKnownFileVersion;
+	}
 
-	void setFileCurrentTimestamp(time_t val) { m_fileCurrentTimestamp = val; }
+	void setLastKnownFileVersion(FileVersion const& version) {
+		m_lastKnownFileVersion = version;
+	}
 	
 	void unselectTextOnce();
 	
 	void updateState();
 	
-	bool updateFileCurrentTimestamp(); // returns true if changed
+	bool updateLastKnownFileVersion(); // returns true if changed
 	
 	virtual wxString const& getTabName() const = 0;
 	
-	virtual time_t getFileEffectiveTimestamp() const { return 0; }
+	virtual FileVersion getEffectiveFileVersion() const {
+		return FileVersion::undefined();
+	}
 	
-	virtual time_t readFileCurrentTimestamp() const { return 0; }
+	virtual FileVersion readCurrentFileVersion() const {
+		return FileVersion::undefined();
+	}
 	
 	virtual void loadFile() = 0;
 	
@@ -152,8 +168,8 @@ private:
 	TextControl* m_pTextControl;
 	State m_state;
 	bool m_textHasBeenUnselected;
-	time_t m_fileLoadTimestamp;
-	time_t m_fileCurrentTimestamp;
+	FileVersion m_loadedFileVersion;
+	FileVersion m_lastKnownFileVersion;
 	bool m_isModified;
 	
 	DECLARE_EVENT_TABLE()
@@ -171,9 +187,9 @@ public:
 	
 	virtual wxString const& getTabName() const;
 	
-	virtual time_t getFileEffectiveTimestamp() const;
+	virtual FileVersion getEffectiveFileVersion() const;
 	
-	virtual time_t readFileCurrentTimestamp() const;
+	virtual FileVersion readCurrentFileVersion() const;
 	
 	virtual void loadFile();
 	
@@ -181,8 +197,6 @@ public:
 	
 	virtual void onSave();
 private:
-	bool restoreOldConfig(Config const& config);
-	
 	wxString m_unmodifiedTabName;
 	wxString m_modifiedTabName;
 };
@@ -233,9 +247,9 @@ public:
 	
 	virtual wxString const& getTabName() const;
 	
-	virtual time_t getFileEffectiveTimestamp() const;
+	virtual FileVersion getEffectiveFileVersion() const;
 	
-	virtual time_t readFileCurrentTimestamp() const;
+	virtual FileVersion readCurrentFileVersion() const;
 	
 	virtual void loadFile();
 	
@@ -431,7 +445,7 @@ AdvancedConfigWindow::onWindowActivate(wxActivateEvent& evt)
 	if (active) {
 		for (int i = m_pNotebook->GetPageCount() - 1; i >= 0; --i) {
 			Page* page = getPage(i);
-			if (page->updateFileCurrentTimestamp()) {
+			if (page->updateLastKnownFileVersion()) {
 				page->updateState();
 			}
 		}
@@ -492,6 +506,9 @@ AdvancedConfigWindow::updateLineColInfo(Page* page)
 void
 AdvancedConfigWindow::onTabChanged(wxNotebookEvent& evt)
 {
+	if (!m_isConstructionFinished) {
+		return;
+	}
 	int selection = evt.GetSelection();
 	Page* page = getPage(selection);
 	page->unselectTextOnce();
@@ -614,8 +631,6 @@ AdvancedConfigWindow::Page::Page(
 	m_notebookPage(notebook_page),
 	m_pTextControl(0),
 	m_textHasBeenUnselected(false),
-	m_fileLoadTimestamp(0),
-	m_fileCurrentTimestamp(0),
 	m_isModified(false)
 {
 	SetClientData(this);
@@ -681,9 +696,9 @@ AdvancedConfigWindow::Page::updateState()
 {
 	bool const text_modified = isTextModified();
 	bool const file_is_newer =
-		(m_fileCurrentTimestamp != m_fileLoadTimestamp);
+		(m_lastKnownFileVersion != m_loadedFileVersion);
 	bool const file_not_effective =
-		(getFileEffectiveTimestamp() != m_fileLoadTimestamp);
+		(getEffectiveFileVersion() != m_loadedFileVersion);
 	
 	bool const was_modified = m_isModified;
 	m_isModified = text_modified || file_not_effective;
@@ -705,12 +720,12 @@ AdvancedConfigWindow::Page::updateState()
 }
 
 bool
-AdvancedConfigWindow::Page::updateFileCurrentTimestamp()
+AdvancedConfigWindow::Page::updateLastKnownFileVersion()
 {
-	time_t const new_tstamp = readFileCurrentTimestamp();
-	time_t const old_tstamp = getFileCurrentTimestamp();
-	setFileCurrentTimestamp(new_tstamp);
-	return (old_tstamp != new_tstamp);
+	FileVersion const current(readCurrentFileVersion());
+	FileVersion const last_known(getLastKnownFileVersion());
+	setLastKnownFileVersion(current);
+	return (current != last_known);
 }
 
 void
@@ -741,22 +756,17 @@ AdvancedConfigWindow::ConfigPage::getTabName() const
 	return isModified() ? m_modifiedTabName : m_unmodifiedTabName;
 }
 
-time_t
-AdvancedConfigWindow::ConfigPage::getFileEffectiveTimestamp() const
+FileVersion
+AdvancedConfigWindow::ConfigPage::getEffectiveFileVersion() const
 {
-	return EffectiveFileTimestamps::config;
+	return GlobalState::ReadAccessor()->getConfigFileVersion();
 }
 
-time_t
-AdvancedConfigWindow::ConfigPage::readFileCurrentTimestamp() const
+FileVersion
+AdvancedConfigWindow::ConfigPage::readCurrentFileVersion() const
 {
-	Application& app = wxGetApp();
-	ACE_stat st;
-	wxString const path = app.getConfigFileName().GetFullPath();
-	if (ACE_OS::stat(path.c_str(), &st) != -1) {
-		return st.st_mtime;
-	}
-	return 0;
+	Application& app = *Application::instance();
+	return app.configFile().readFileVersion();
 }
 
 void
@@ -764,10 +774,10 @@ AdvancedConfigWindow::ConfigPage::loadFile()
 {
 	Application& app = wxGetApp();
 	string content;
-	time_t mtime = 0;
-	app.readFile(app.getConfigFileName(), content, &mtime);
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
+	FileVersion version;
+	FileOps::readFile(app.getConfigFileName(), content, &version);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setText(content.c_str());
 }
 
@@ -780,63 +790,21 @@ AdvancedConfigWindow::ConfigPage::onReload()
 void
 AdvancedConfigWindow::ConfigPage::onSave()
 {
-	Application& app = wxGetApp();
-	Log* log = OperationLog::instance();
-	log->appendRecord(_T("Applying new config ... "));
-	size_t num_records = log->getNumRecords();
-	
-	string const text = getText();
-	Config new_config;
-	ConfigFile new_config_file;
-	
-	if (!app.processConfig(text, new_config, new_config_file)) {
+	Application& app = *Application::instance();
+
+	if (!app.configFile().applyAndSave(getText())) {
 		return;
 	}
 	
-	Config old_config(GlobalState::ReadAccessor()->config());
-	
-	if (!app.applyConfig(new_config)) {
-		restoreOldConfig(old_config);
-		return;
-	}
-	
-	time_t mtime = 0;
-	if (!app.writeFile(app.getConfigFileName(), text, &mtime)) {
-		restoreOldConfig(old_config);
-		return;
-	}
-	
-	app.configFile().swap(new_config_file);
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord(_T("done"), log->getSuccessStyle());
-	}
-	
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	EffectiveFileTimestamps::config = mtime;
+	FileVersion const version(
+		GlobalState::ReadAccessor()->getConfigFileVersion()
+	);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setTextUnmodified();
 	updateState();
 }
 
-bool
-AdvancedConfigWindow::ConfigPage::restoreOldConfig(Config const& config)
-{
-	Application& app = wxGetApp();
-	Log* log = OperationLog::instance();
-	log->appendRecord(_T("Restoring the old config ... "));
-	size_t num_records = log->getNumRecords();
-	
-	if (!app.applyConfig(config)) {
-		return false;
-	}
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord(_T("done"), log->getSuccessStyle());
-	}
-	return true;
-}
-
 
 /*============= AdvancedConfigWindow::ConfigDefaultPage =================*/
 
@@ -863,7 +831,7 @@ AdvancedConfigWindow::ConfigDefaultPage::loadFile()
 {
 	Application& app = wxGetApp();
 	string content;
-	app.readFile(app.getConfigDefaultFileName(), content);
+	FileOps::readFile(app.getConfigDefaultFileName(), content);
 	setText(content.c_str());
 }
 
@@ -893,7 +861,7 @@ AdvancedConfigWindow::UrlsPage::loadFile()
 {
 	Application& app = wxGetApp();
 	string content;
-	app.readFile(app.getStandardUrlPatternsFileName(), content);
+	FileOps::readFile(app.getStandardUrlPatternsFileName(), content);
 	setText(content.c_str());
 }
 
@@ -919,22 +887,17 @@ AdvancedConfigWindow::UrlsLocalPage::getTabName() const
 	return isModified() ? m_modifiedTabName : m_unmodifiedTabName;
 }
 
-time_t
-AdvancedConfigWindow::UrlsLocalPage::getFileEffectiveTimestamp() const
+FileVersion
+AdvancedConfigWindow::UrlsLocalPage::getEffectiveFileVersion() const
 {
-	return EffectiveFileTimestamps::urls_local;
+	return GlobalState::ReadAccessor()->getUrlsLocalFileVersion();
 }
 
-time_t
-AdvancedConfigWindow::UrlsLocalPage::readFileCurrentTimestamp() const
+FileVersion
+AdvancedConfigWindow::UrlsLocalPage::readCurrentFileVersion() const
 {
 	Application& app = wxGetApp();
-	ACE_stat st;
-	wxString const path = app.getLocalUrlPatternsFileName().GetFullPath();
-	if (ACE_OS::stat(path.c_str(), &st) != -1) {
-		return st.st_mtime;
-	}
-	return 0;
+	return FileOps::readFileVersion(app.getLocalUrlPatternsFileName());
 }
 
 void
@@ -942,10 +905,10 @@ AdvancedConfigWindow::UrlsLocalPage::loadFile()
 {
 	Application& app = wxGetApp();
 	string content;
-	time_t mtime = 0;
-	app.readFile(app.getLocalUrlPatternsFileName(), content, &mtime);
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
+	FileVersion version;
+	FileOps::readFile(app.getLocalUrlPatternsFileName(), content, &version);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setText(content.c_str());
 }
 
@@ -958,34 +921,19 @@ AdvancedConfigWindow::UrlsLocalPage::onReload()
 void
 AdvancedConfigWindow::UrlsLocalPage::onSave()
 {
-	Application& app = wxGetApp();
-	Log* log = OperationLog::instance();
-	log->appendRecord(_T("Applying new local url patterns ... "));
-	size_t num_records = log->getNumRecords();
-	
-	string const text = getText();
-	UrlPatterns new_patterns;
-	UrlPatternsFile new_patterns_file;
-	
-	if (!app.processUrlPatterns(text, _T("urls.local"),
-		                    new_patterns, new_patterns_file)) {
+	Application& app = *Application::instance();
+
+	if (!app.urlsLocalFile().applyAndSave(getText())) {
 		return;
 	}
 	
-	time_t mtime = 0;
-	if (!app.writeFile(app.getLocalUrlPatternsFileName(), text, &mtime)) {
-		return;
-	}
-	
-	app.applyLocalUrlPatterns(new_patterns);
-	
-	if (num_records == log->getNumRecords()) {
-		log->appendToLastRecord(_T("done"), log->getSuccessStyle());
-	}
-	
-	setFileLoadTimestamp(mtime);
-	setFileCurrentTimestamp(mtime);
-	EffectiveFileTimestamps::urls_local = mtime;
+	FileVersion const version(
+		GlobalState::ReadAccessor()->getUrlsLocalFileVersion()
+	);
+	setLoadedFileVersion(version);
+	setLastKnownFileVersion(version);
 	setTextUnmodified();
 	updateState();
 }
+
+} // namespace wxGUI
