@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@
 #include <wx/string.h>
 #include <vector>
 
+namespace wxGUI
+{
+
 class AnimatedTrayIcon : public wxTaskBarIcon
 {
 public:
@@ -121,4 +124,6 @@ AnimatedTrayIcon::setAnimation(
 	}
 }
 
+} // namespace wxGUI
+
 #endif
