@@ -42,7 +42,12 @@
 #include "WorkerThreadPoolExSingleton.h"
 #include "ScopedIncDec.h"
 #include "AtomicOps.h"
+#include "Log.h"
+#include "OperationLog.h"
+#include "TwoPhaseLogRecord.h"
+#include "cache/ObjectStorage.h"
 #include <wx/wx.h>
+#include <wx/log.h>
 #include <wx/event.h>
 #include <wx/image.h>
 
@@ -59,7 +64,9 @@ END_EVENT_TABLE()
 
 
 Application::Application()
-:	m_isExiting(false),
+:	m_mainCacheMutex(USYNC_PROCESS, "Global\\BFilterCacheAccess"),
+	m_isMainCacheOwner(false),
+	m_isExiting(false),
 	m_commandNestLevel(0),
 	m_havePendingCommands(0),
 	m_commandQueue(COMMAND_QUEUE_CAPACITY, *this),
@@ -67,6 +74,7 @@ Application::Application()
 	m_filterJsLogHandler(m_commandQueue),
 	m_requestLogHandler(m_commandQueue)
 {
+	m_isMainCacheOwner = (m_mainCacheMutex.tryacquire() == 0);
 }
 
 Application::~Application()
@@ -90,7 +98,14 @@ Application::OnInit()
 	));
 	m_confDir.Assign(m_appDir);
 	m_confDir.AppendDir(_T("conf"));
+	m_mainCacheDir.Assign(m_appDir);
+	m_mainCacheDir.AppendDir(_T("cache"));
 	
+	if (m_isMainCacheOwner) {
+		wxLogNull log_disabler;
+		m_mainCacheDir.Mkdir();
+	}
+
 	{
 		wxFileName config_fname(m_confDir);
 		config_fname.SetName(_T("config"));
@@ -140,6 +155,7 @@ Application::OnInit()
 	m_ptrUrlsFile->loadAndForceApply();
 	m_ptrUrlsLocalFile->loadAndForceApply();
 	m_ptrContentFilters->loadAndApply();
+	loadCache();
 	if (errors) {
 		showLogDialog();
 	}
@@ -336,4 +352,32 @@ Application::processCommands()
 	notifyCommandsPending(); // there could be more commands in the queue
 }
 
+bool
+Application::loadCache()
+{
+	Log* log = OperationLog::instance();
+	TwoPhaseLogRecord log_record(log,
+		StyledText(_T("Loading cache ... "), log->getDefaultStyle()),
+		StyledText(_T("done"), log->getSuccessStyle())
+	);
+	
+	if (!m_isMainCacheOwner ||
+		GlobalState::ReadAccessor()->config().getCacheSize() == 0) {
+		log_record.setSecondPhaseMessage(
+			StyledText(_T("disabled"), log->getDefaultStyle())
+		);
+		return true;
+	}
+	
+	HttpCache::ObjectStorage* storage = HttpCache::ObjectStorage::instance();
+	if (!storage->setCacheDir(m_mainCacheDir.GetFullPath().fn_str())) {
+		log_record.setSecondPhaseMessage(
+			StyledText(_T("failed"), log->getErrorStyle())
+		);
+		return false;
+	}
+	
+	return true;
+}
+
 } // namespace wxGUI
