@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,9 @@
 
 class wxCommandEvent;
 
+namespace wxGUI
+{
+
 class AutoIndentingTextCtrl : public wxTextCtrl
 {
 public:
@@ -48,4 +51,6 @@ private:
 	DECLARE_EVENT_TABLE()
 };
 
+} // namespace wxGUI
+
 #endif
