@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #include <wx/colour.h>
 #include <wx/font.h>
 
+namespace wxGUI
+{
 
 Log::Log()
 :	m_numRecords(0),
@@ -144,3 +146,5 @@ Log::onViewVisibilityChange(bool visible)
 		}
 	}
 }
+
+} // namespace wxGUI
