@@ -320,6 +320,8 @@ RequestLogHandler::ListModel::processResponseEnd(
 	} else if (row.type == RequestLog::SUBST_REQUEST ||
 		   (req_flags & RequestTag::RESPONSE_CRAFTED)) {
 		icon = RequestLogIcons::ICON_AD;
+	} else if (req_flags & RequestTag::RESPONSE_CACHED) {
+		icon = RequestLogIcons::ICON_CACHE;
 	} else {
 		int const scode = row.status_code;
 		if (scode >= 400) {
