@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,8 +24,13 @@
 #include <config.h>
 #endif
 
+#include <ace/config-lite.h>
+#include <wx/image.h> // because wx/imagelist.h forgets to include defs.h
 #include <wx/imaglist.h>
 
+namespace wxGUI
+{
+
 class RequestLogIcons
 {
 public:
@@ -47,4 +52,6 @@ private:
 	wxImageList m_images;
 };
 
+} // namespace wxGUI
+
 #endif
