@@ -1,6 +1,6 @@
 /*
     BFilter - a smart ad-filtering web proxy
-    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>
+    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 #include <ace/config-lite.h>
 #include <wx/textctrl.h>
 
+namespace wxGUI
+{
+
 class TextStyle : public wxTextAttr
 {
 public:
@@ -38,4 +41,6 @@ private:
 	mutable AtomicCounter<ACE_NULL_SYNCH> m_refCounter;
 };
 
+} // namespace wxGUI
+
 #endif
