@@ -22,6 +22,7 @@
 
 #include <CoreFoundation/CoreFoundation.h>
 #include "RefPtr.h"
+#include <string>
 
 class CFUtils
 {
@@ -33,7 +34,9 @@ public:
 	static StringRef extractLastPathComponent(StringRef const& path);
 	
 	static StringRef removeStringPrefix(
-		StringRef const& string, CFStringRef const& prefix);
+		StringRef const& string, CFStringRef prefix);
+	
+	static std::string stringToUtf8(CFStringRef str);
 };
 
 #endif
