@@ -29,6 +29,10 @@
 #include <utility>
 
 class NetworkPrefs;
+namespace Forwarding
+{
+	class SystemOption;
+}
 
 class ProxyWatcher
 {
@@ -64,25 +68,27 @@ private:
 	static StringRef findServiceBySetAndDeviceName(
 		NetworkPrefs& prefs, StringRef const& set_id, StringRef const& device_name);
 	
-	static void getProxiesFromService(DictRef const& service);
+	static void getProxiesFromService(DictRef const& service, StringRef const& set_name);
 	
-	static bool isProxyEnabled(
-		DictRef const& proxies, CFStringRef key);
+	static bool isFlagSet(
+		DictRef const& dict, CFStringRef key);
 	
-	static void processHttpProxy(DictRef const& proxies);
+	static void processHttpProxy(
+		DictRef const& proxies, Forwarding::SystemOption& sys_opt);
 	
-	static void processSocksProxy(DictRef const& proxies);
+	static void processSocksProxy(
+		DictRef const& proxies, Forwarding::SystemOption& sys_opt);
 	
-	static void processProxyAutoDiscovery(DictRef const& proxies);
+	static void processProxyAutoDiscovery(
+		DictRef const& proxies, Forwarding::SystemOption& sys_opt);
 	
-	static void processProxyAutoConfig(DictRef const& proxies);
+	static void processProxyAutoConfig(
+		DictRef const& proxies, Forwarding::SystemOption& sys_opt);
 	
-	static void readProxySkipList(
-		DictRef const& proxies, OutputFunction<std::string>& output);
+	static void readProxyBypassList(
+		DictRef const& proxies, Forwarding::SystemOption& sys_opt);
 	
-	static void setNoProxy();
-	
-	static void setGenericError(std::string const& msg);
+	static void setUnmaskableError(std::string const& msg);
 	
 	RefPtr<SCDynamicStoreRef> m_ptrStore;
 	StringRef m_ptrClientName;
