@@ -8,7 +8,8 @@ COMMON_CFLAGS="-Wall -Wno-unused -mcpu=i586 -mtune=i686 -Os -fvisibility=hidden
 
 export PKG_CONFIG_PATH="$PREFIX/lib/pkgconfig:$PKG_CONFIG_PATH";
 export APBUILD_INCLUDE="$PREFIX/gtk-headers/2.4:$PREFIX/include:$PREFIX/include/c++/current"
-export APBUILD_STATIC="ACE gtkmm-2.4 gdkmm-2.4 atkmm-1.6 pangomm-1.4 glibmm-2.4 sigc-2.0"
+export APBUILD_STATIC="ACE=$PREFIX/lib/libACE.a gtkmm-2.4 gdkmm-2.4 atkmm-1.6 pangomm-1.4 glibmm-2.4 sigc-2.0"
+export APBUILD_NO_STATIC_X=1
 export LDFLAGS="-L$PREFIX/lib -Wl,--gc-sections"
 export LIBS="-lstdc++"
 
@@ -21,7 +22,7 @@ CFLAGS="$COMMON_CFLAGS -fno-strict-aliasing" CXXFLAGS="$COMMON_CFLAGS" || exit 1
 make CC=apgcc CXX=apg++ || exit 1
 make DESTDIR="$APKG_BUILD_ROOT" uninstall all install || exit 1
 cd ../../../../ || exit 1
-makeinstaller -c -m "$APKG_BUILD_ROOT/packaging/autopackage/bfilter-gui.apspec" || exit 1
+makepackage -c -m "$APKG_BUILD_ROOT/packaging/autopackage/bfilter-gui.apspec" || exit 1
 cd "$APKG_BUILD_ROOT" || exit 1
 make DESTDIR="$APKG_BUILD_ROOT" uninstall > /dev/null
 echo
