@@ -8,6 +8,9 @@
 #else
 #  define ACE_HAS_WINNT4 1
 #  define ACE_HAS_IPV6
+#  ifndef _WIN32_WINNT
+#    define _WIN32_WINNT 0x0501 /* Necessary for newer Platform SDK's. */
+#  endif
 #endif
 
 #include "config-win32.h"
