@@ -32,7 +32,8 @@ ReactorFactory::createBestReactor(
 	AbstractSynchFactory const& synch_factory, bool wakeup_on_interrupt)
 {
 	std::auto_ptr<Reactor> res;
-#if defined(HAVE_WFMO_REACTOR)
+#if defined(HAVE_WFMO_REACTOR) && ACE_HAS_WINNT4
+	// for some reason WFMOReactor doesn't work on Win9x
 	res.reset(new WFMOReactor(synch_factory));
 #elif defined(HAVE_POLL_REACTOR)
 	res.reset(new PollReactor(synch_factory, wakeup_on_interrupt));
