@@ -161,10 +161,11 @@ TimerQueue::updateDispatchThreshold()
 	// because of the low resolution of the system timer.
 }
 
-void
+bool
 TimerQueue::continueDispatching(ACE_Lock& mutex, bool& is_stopped)
 {
 	assert(m_dispatchThreshold < TimeStamp::max());
+	bool progress_made = false;
 	while (!is_stopped && !empty()) {
 		iterator it = begin();
 		if (it->abs_time > m_dispatchThreshold) {
@@ -175,9 +176,13 @@ TimerQueue::continueDispatching(ACE_Lock& mutex, bool& is_stopped)
 		replace(it, Timer(it->handler, TimeStamp::max()));
 		
 		ReactorTimerId timer_id(it);
-		MtAntiGuard<ACE_Lock> anti_guard(mutex);
-		it->handler->handleTimeout(timer_id);
+		{
+			MtAntiGuard<ACE_Lock> anti_guard(mutex);
+			it->handler->handleTimeout(timer_id);
+		}
+		progress_made = true;
 	}
+	return progress_made;
 }
 
 TimeStamp
