@@ -142,7 +142,7 @@ public:
 	
 	void updateDispatchThreshold();
 	
-	void continueDispatching(ACE_Lock& mutex, bool& is_stopped);
+	bool continueDispatching(ACE_Lock& mutex, bool& is_stopped);
 	
 	static ReactorTimerId iterToId(iterator const& it) {
 		return ReactorTimerId(it);
