@@ -218,8 +218,8 @@ int createSocketPairWin32(ACE_HANDLE handles[2])
 	handles[1] = writer.get_handle();
 	
 	// prevent auto-closing
-	reader.set_handle(ACE_INVALID_HANDLE);
-	writer.set_handle(ACE_INVALID_HANDLE);
+	reader.release();
+	writer.release();
 		
 	return 0;
 }
