@@ -21,27 +21,18 @@
 #include <config.h>
 #endif
 
-#include "IPv4SubnetParserTestSuite.h"
-#include "HtmlLexerTestSuite.h"
-#include "XmlLexerTestSuite.h"
-#include "ForwardingTestSuite.h"
-#include "FilterOrderingTestSuite.h"
-#include "HeuristicScoreTestSuite.h"
-#include <boost/test/unit_test.hpp>
-#include <memory>
+#define BOOST_AUTO_TEST_MAIN
 
-using boost::unit_test_framework::test_suite;
+#include "Color.h"
+#include "FilterJsLogger.h"
+#include "HtmlEscaper.h"
+#include <boost/test/auto_unit_test.hpp>
 
-test_suite* init_unit_test_suite(int, char*[])
+BOOST_AUTO_UNIT_TEST(test_noop)
 {
-	test_suite* top_ts = BOOST_TEST_SUITE("Master test suite");
-	
-	top_ts->add(new IPv4SubnetParserTestSuite);
-	top_ts->add(new HtmlLexerTestSuite);
-	top_ts->add(new XmlLexerTestSuite);
-	top_ts->add(new ForwardingTestSuite);
-	top_ts->add(new FilterOrderingTestSuite);
-	top_ts->add(new HeuristicScoreTestSuite);
-	
-	return top_ts;
+    // Create references to certain objects,
+	// to prevent link-time errors.
+	Color color(0, 0, 0);
+	FilterJsLogger::setHandler(0);
+	HtmlEscaper::escape("");
 }
